@@ -23,6 +23,9 @@ import gobject
 import paths
 import emesenelib.common
 
+import random
+id = 'emesene'+str(random.random()) #used for dp roaming
+
 DEFAULT_GLOBAL_CONFIG = {
     'rememberMe': True,
     'rememberMyPassword': False,
@@ -34,10 +37,7 @@ DEFAULT_GLOBAL_CONFIG = {
     'proxyPort': 80,
     'proxyUsername' : '',
     'proxyPassword' : '',
-    'mainWindowWidth': 260,
-    'mainWindowHeight': 440,
-    'mainWindowX': -1,
-    'mainWindowY': -1,
+    'mainWindowGeometry': '440x260+0+0',
     'autoLogin': False,
     'lastLoggedAccount': '',
     'rgbaColormap' : False,
@@ -45,6 +45,7 @@ DEFAULT_GLOBAL_CONFIG = {
     'overrideDesktop' : '',
     'overrideMail' : '',
     'startup' : 'default',
+    'Id' : id,
     'dontShowAvatarInLoginWindow' : 0,
 }
 
@@ -70,10 +71,12 @@ DEFAULT_USER_CONFIG = {
     'fontItalic' : False,
     'fontStrike' : False,
     'showTimestamp': False, # XXX: check if this works
-    'convWindowWidth': 450,
-    'convWindowHeight': 480,
+    'convWindowGeometry': '480x450+0+0',
+    'convWindowWidth': '450',
+    'convWindowHeight': '480',
     'convInputHeight' : 140,
     'convListWidth' : 130,
+    'convMaximized' : False,
     'saveLogsAutomatically' : False,
     'activePlugins': 'Plus', # CSV of plugin names
     'emoticonDir': '',
@@ -96,7 +99,8 @@ DEFAULT_USER_CONFIG = {
     'showUserPanel' : True,
     'showSearchEntry' : True,
     'showStatusCombo' : True,
-    'statusComboOnTop' : False,
+    #'statusComboOnTop' : False,
+    'statusComboPos' : 0,
     'showMenubar' : True,
     'showMenu' : True,
     'showHeader' : True,
