@@ -50,7 +50,6 @@ import StatusMenu
 import SlashCommands
 import Sound
 import PluginManager
-import PluginManagerDialog
 import ConversationManager
 import ConversationLayoutManager
 from Parser import UnifiedParser
@@ -93,6 +92,9 @@ class Controller(gobject.GObject):
         ()),
         'usermenu-item-add' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
         (gobject.TYPE_PYOBJECT,)),
+        
+        'message-read' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            ()),
     }
 
     def __init__(self, username, minimized, leakdebug, iconified, badroot):
@@ -100,8 +102,8 @@ class Controller(gobject.GObject):
         gobject.GObject.__init__(self)
 
         self.NAME = 'emesene'
-        self.VERSION = '1.6 "mate"'
-        self.COPYRIGHT = 'Luis Mariano Guerra, dx, C10uD'
+        self.VERSION = '1.6.1 "mate"'
+        self.COPYRIGHT = 'Luis Mariano Guerra, dx, C10uD, arielj'
         self.COMMENT = _('A client for the WLM%s network') % u'\u2122'
         self.LICENSE_FALLBACK = 'GNU General Public License'
         self.WEBSITE = 'http://www.emesene.org'
@@ -140,6 +142,7 @@ class Controller(gobject.GObject):
             'GrinningArmor (emesene)', \
             'x-warrior (emesene)', \
             'Tom \'ukblackknight\' (emesene)', \
+            'Stefano \'Cando\' Candori (emesene)', \
             'All the fantastic emesene community (all)', \
             ]
         
@@ -213,7 +216,7 @@ class Controller(gobject.GObject):
             gtk.widget_pop_colormap()
 
         if TrayIcon.disabled or not (minimized or self.config.glob['startup'] == 'minimize'):
-            if iconified or self.config.glob['startup'] == 'iconify':
+            if iconified or self.config.glob['startup'] == 'iconify' and not self.config.glob['disableTrayIcon']:
                 self.mainWindow.iconify()
             else:
                 self.mainWindow.show()
@@ -290,7 +293,7 @@ class Controller(gobject.GObject):
         # messenger.hotmail.com
         self.msn = core.Msnp(server, 1863, user, password,\
              self.config.getUserConfigPath(), proxy, \
-             self.config.user['receiveP4context']) # ugly, but i'm lazy
+             self.config.user['receiveP4context'], self.config) # ugly, but i'm lazy
                     
         self.msn.setDebug(self.config.glob['debug'],
             self.config.glob['binary'])
@@ -321,10 +324,13 @@ class Controller(gobject.GObject):
         if not self.msn:
             return False
         if not self.reconnecting:
-            text = _('Error during login, please retry') + \
-             '\n(' + message + ')'
-            self.goToLoginWindow()
-            self.mainWindow.showNiceBar(text,self.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)
+            if self.config.glob['autoLogin']:
+                self.autoReconnect(self.userEmail, password, self.userStatus)
+            else:    
+                text = _('Error during login, please retry') + \
+                '\n(' + message + ')'
+                self.goToLoginWindow()
+                self.mainWindow.showNiceBar(text,self.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)
         else:
             self.autoReconnect(self.userEmail, password, self.userStatus)
 
@@ -334,6 +340,9 @@ class Controller(gobject.GObject):
         except Exception, e:
             print "Exception at logout", e
         self.goToLoginWindow()
+        if self.reconnectTimerId is not None:
+            gobject.source_remove(self.reconnectTimerId)
+            self.reconnectTimerId = None
 
     def goToLoginWindow(self):
         self.config.setCurrentUser('')
@@ -423,7 +432,7 @@ class Controller(gobject.GObject):
             self.trayIcon.menu.prepend(self.trayStatusMenu)
             self.trayIcon.menu.show_all()
             self.trayIcon.update(self.msn.status)
-
+            
         self.pluginManager = PluginManager.PluginManager(self)
         gobject.idle_add(self.pluginManager.startActivePlugins)
 
@@ -433,6 +442,7 @@ class Controller(gobject.GObject):
         self.msn.connect('new-conversation', self.newConversation)
         self.msn.connect('user-attr-changed', self.on_user_attr_changed)
         self.msn.connect('self-status-changed', self.on_self_status_changed)
+        self.msn.connect('self-dp-changed', self.on_change_avatar)
         self.msn.connect('group-attr-changed', self.on_group_attr_changed)
         self.msn.connect('add-notification', self.addNotification)
         self.msn.connect('user-list-change', self.refreshUserList)
@@ -507,12 +517,14 @@ class Controller(gobject.GObject):
 
     def removeGroup(self, group):
         #asks the user before removing the group
-        def remove_cb(response):
+        def remove_cb(response, group):
             if response == stock.YES:
-                self.groups.remove(group.name)
+                if not isinstance(group, basestring):
+                    group = group.name
+                self.groups.remove(group)
 
         message = _('Are you sure you want to remove this group?')
-        dialog.yes_no(message,remove_cb)
+        dialog.yes_no(message,remove_cb, group)
 
     def autoReconnect(self, user, password, status):
         self.mainWindow.buildInterface('reconnect')
@@ -613,6 +625,14 @@ class Controller(gobject.GObject):
             code.InteractiveConsole(locals()).interact(\
                 "Entering controller.msn leak debug console")
 
+        hotmail_file = os.path.join(paths.CONFIG_DIR, \
+            self.config.getCurrentUser(), "cache", "login.htm")
+
+        if os.path.isfile(hotmail_file):
+            try:
+                os.remove(hotmail_file)
+            except:
+                pass
 
     def quit(self, status):
         '''close the window, and do all the things needed...'''
@@ -622,7 +642,7 @@ class Controller(gobject.GObject):
         #self.mainWindow.connect('unmap-event', self.on_main_hidden, status)
         self.mainWindow.hide()
         if not TrayIcon.disabled:
-            self.trayIcon.tray.hide()
+            self.trayIcon.remove()
 
         try:
             self.mainWindow.saveToQuit()
@@ -630,7 +650,8 @@ class Controller(gobject.GObject):
             pass
 
         if self.connected:
-            self.msn.logout()
+            self.logout()
+            #self.msn.logout()
             self.config.writeUserConfig()
 
         self.config.writeGlobalConfig()
@@ -676,11 +697,19 @@ class Controller(gobject.GObject):
                 if avatarPath != self.config.user['avatarPath']:
                     self.changeAvatar(avatarPath)
 
-        nick=self.contacts.get_nick()
-        psm=self.contacts.get_message()
+        nick=self.msn.nick.replace('\n', ' ')
+        psm=self.msn.personalMessage.replace('\n', ' ')
         currentAvatarPath = self.config.user['avatarPath']
         dialog.show_profile(self, nick, psm, currentAvatarPath, responseProfile)
 
+    def on_change_avatar(self, msnp, filename):
+        '''control if the avatar already exists or save the new avatar'''
+        if os.path.exists(filename):
+            self.changeAvatar(filename)
+            return
+        else:
+            return
+
     def changeAvatar(self, filename):
         if not self.msn:
             return
@@ -833,13 +862,6 @@ class Controller(gobject.GObject):
         return self.conversationManager.newConversation(self.msn, mail, \
             switchboard, weStarted)
 
-    def pluginDialog(self):
-        '''Show the pluginManagerDialog'''
-
-        p = PluginManagerDialog.PluginManagerDialog(self.pluginManager, \
-            self.mainWindow, self.config)
-        p.show()
-
     def seeAvatarHistory(self, email):
        '''opens a dialog with all user's avatars'''
 
@@ -858,6 +880,7 @@ class Controller(gobject.GObject):
         '''process the OIM message'''
         user, date, message = oim
         window, conv = self.newConversation(msnp, user['addr'], None, False)
+        self.conversationManager.newest_message_conv = conv
         conv.receiveOIM(user['name'], message, date)
 
     def messageError(self, msnp, to, message, error):
@@ -945,7 +968,7 @@ def debug(msg):
 
 def main():
     args = parseArgs()
-    if (os.name == 'posix') and (os.getuid() == 0) and (args[5] == False):
+    if (os.name == 'posix') and (os.getuid() == 0) and (args[4] == False):
         print "I refuse to run as root. " \
               "If you know the risks and still want to do it," \
               " just add the --i-know-that-running-emesene-as-root-is-bad option."
@@ -972,7 +995,11 @@ def main():
     # this stuff is to interrupt blocking stuff safely.
     for i in range(5):
         try:
+            gtk.gdk.threads_init()
+            gtk.gdk.threads_enter()
             gtk.main()
+            gtk.gdk.threads_leave()
+            
         except KeyboardInterrupt:
             print 'Interrupt (%s more times to close)' % str(5 - i)
         else:
