@@ -49,10 +49,14 @@ class OurStatusBar(gtk.Statusbar):
     def __init__(self, ui):    
         gtk.Statusbar.__init__(self)
         self.ui = ui
-        # this hack skips the statusbar stack
-        self.label = self.get_children()[0].get_children()[0]
+        self.genericID = 1
+        self.message_id = None
     def set_text(self, text):
-        self.label.set_text(text)
+        if self.message_id is not None:
+            self.pop(self.genericID)
+            self.message_id = None
+        if text != "":
+            self.message_id = self.push(self.genericID, text)
 
 class ConversationUI(gtk.VBox):
     '''this class represent all the widgets that are inside a tab
@@ -155,9 +159,9 @@ class ConversationUI(gtk.VBox):
         self.hbox.set_border_width(2)
         if avatarRight:
             self.hbox.pack_start(self.mainPaned, True, True)
-            self.hbox.pack_start(self.remoteAvatar, False, False)
+            self.hbox.pack_start(self.remoteAvatar, False, False, padding = 1)
         else:
-            self.hbox.pack_start(self.remoteAvatar, False, False)
+            self.hbox.pack_start(self.remoteAvatar, False, False, padding = 1)
             self.hbox.pack_start(self.mainPaned, True, True)
         
         self.hbox.show()
@@ -185,7 +189,6 @@ class ConversationUI(gtk.VBox):
         self.messageWaiting = {}
         self.contactTyping = {}
 
-
         self.typingTimeoutID = 0
         self.closed = False
 
@@ -226,6 +229,7 @@ class ConversationUI(gtk.VBox):
 
     def close(self):
         self.closed = True
+        self.remoteAvatar.close()
 
     def setInputEnabled(self, enable):
         self.input.input.set_sensitive(enable)
@@ -255,6 +259,8 @@ class ConversationUI(gtk.VBox):
         for email in self.contactTyping.keys():
             if self.contactTyping[email]:
                 self.setTyping(email)
+            elif self.messageWaiting[email]:
+                self.setMessageWaiting(email)
             else:
                 self.setDefault(email)
 
@@ -682,7 +688,7 @@ class Header(gtk.HBox):
         ret = self.parentUI.parentConversation.view_webcam()
         if ret == 1:
             dialog.error(\
-                'You don\'t have libmimic, so you can\'t send or receive webcam') 
+                _('You don\'t have libmimic, so you can\'t send or receive webcam'))
         
     def setDefault(self):
         self.setLabel()
@@ -701,9 +707,9 @@ class TabWidget(gtk.HBox):
 
         self.text = ''
         self.markup = ''
-        self.updateText()
         self.hasMessageWaiting = False
-
+        self.updateText()
+        
         self.label = gtk.Label()
         self.label.set_use_markup(True)
         self.label.set_markup(self.markup)
@@ -782,7 +788,6 @@ class AvatarHBox(gtk.HBox):
         self.hidebutton.connect('clicked', self.hideShowButton)
         self.hidebutton.set_relief(gtk.RELIEF_NONE)
         if self.config.user['avatarsOnRight']:
-#            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_RIGHT)
             self.hidebuttonArrow = gtk.Arrow(gtk.ARROW_RIGHT,gtk.SHADOW_NONE)
             self.hidebuttonArrow.set_alignment(1,0.5)
             self.hidebuttonArrow.set_size_request(-1,10)
@@ -790,7 +795,6 @@ class AvatarHBox(gtk.HBox):
             self.hidebuttonArrow = gtk.Arrow(gtk.ARROW_LEFT,gtk.SHADOW_NONE)
             self.hidebuttonArrow.set_alignment(0,0.5)
             self.hidebuttonArrow.set_size_request(-1,10)
-#            self.hidebuttonArrow = Widgets.TinyArrow(gtk.ARROW_LEFT)
         self.hidebutton.add(self.hidebuttonArrow)
 
         self.image = Widgets.avatarHolder(cellKeyPosition=gtk.ANCHOR_SOUTH)
@@ -813,10 +817,13 @@ class AvatarHBox(gtk.HBox):
         saveAsMenuItem.show()   
         
         # if we have an email, this is our contact's avatar
+        self.dpid = None
+        self.atchangeid = None
+        self.avchangeid = None
         if mail:
-            self.controller.msn.connect('display-picture-changed',
+            self.dpid = self.controller.msn.connect('display-picture-changed',
                 self.onDisplayPictureChanged)
-            self.controller.msn.connect('user-attr-changed',
+            self.atchangeid = self.controller.msn.connect('user-attr-changed',
                 self.onDisplayPictureChanged)
             self.imageEventBox.connect('button-press-event', \
                 self.button_clicked)  
@@ -824,7 +831,7 @@ class AvatarHBox(gtk.HBox):
             self.key = 'showAvatarOther'
         else:
             # we don't have an email, so this is our avatar
-            self.controller.connect('avatar-changed',
+            self.avchangeid = self.controller.connect('avatar-changed',
                 self.onDisplayPictureChanged)
 
             self.imageEventBox.connect('button-press-event',
@@ -856,6 +863,12 @@ class AvatarHBox(gtk.HBox):
         self.pack_start(self.container, False, False)
         self.update()
 
+    def close(self):
+        if self.controller.msn is not None:
+            if self.dpid is not None: self.controller.msn.disconnect(self.dpid)
+            if self.atchangeid is not None: self.controller.msn.disconnect(self.atchangeid)
+        if self.avchangeid is not None: self.controller.disconnect(self.avchangeid)
+
     def update(self):
         avatarRight = self.config.user['avatarsOnRight']
         if not self.config.user[self.key]:
@@ -977,6 +990,7 @@ class InputWidget(gtk.HBox):
         self.sendbuttonwin.connect('realize', self.change_cursor)
 
         self.inputBuffer = self.input.get_buffer()
+
         self.scrollInput = gtk.ScrolledWindow()
         self.scrollInput.set_policy(gtk.POLICY_AUTOMATIC,
                                     gtk.POLICY_AUTOMATIC)
@@ -1020,6 +1034,10 @@ class InputWidget(gtk.HBox):
         self.scrollInput.get_vadjustment().connect('value-changed',
             self.move_sendbtn)
 
+        self.input.connect('copy-clipboard', self._on_copy_clipboard)
+        self.clipboard = gtk.Clipboard(selection=gtk.gdk.atom_intern("CLIPBOARD"))
+        self.input.get_buffer().add_selection_clipboard(self.clipboard)
+
         if setFocus:
             self.input.grab_focus()
 
@@ -1059,75 +1077,49 @@ class InputWidget(gtk.HBox):
             return
 
         theme = self.controller.theme
-        emos = []
         customEmo = self.controller.customEmoticons
+        
+        def get_smilie_pixbuf(code, filename=None):
+            if filename is not None:
+                pixbuf = resizePixbuf(gtk.gdk.pixbuf_new_from_file(filename),
+                                      24, 24)
+            else:
+                pixbuf = theme.getSmiley(code, False)
+            return pixbuf
 
-        for code in theme.getSmileysList():
+        def replace_shortcuts(code, filename):
             iter_start = self.inputBuffer.get_start_iter()
             iter_start.set_offset(self.parse_off)
             while iter_start.forward_search(code,
                                 gtk.TEXT_SEARCH_VISIBLE_ONLY):
                 iter_pos, iter_end = iter_start.forward_search(code, \
                     gtk.TEXT_SEARCH_VISIBLE_ONLY)
-                pixbuf = theme.getSmiley(code, False)
-                pixbuf.shortcut = code
-
-                tag = gtk.TextTag()
-                tag.set_property('invisible', True)
-                tagtable = self.inputBuffer.get_tag_table()
-                tagtable.add(tag)
-                self.inputBuffer.apply_tag(tag, iter_pos, iter_end)
 
                 mark1 = self.inputBuffer.create_mark(None, iter_pos)
                 mark2 = self.inputBuffer.create_mark(None, iter_end)
+                
+                self.inputBuffer.delete(iter_pos, iter_end)
+                
+                pixbuf = get_smilie_pixbuf(code, filename)
 
                 img = gtk.Image()
                 img.set_from_pixbuf(pixbuf)
                 img.show()
                 img.shortcut = code
 
-                emos.append((img, mark1, mark2))
-                iter_start = iter_end
+                iterStart = self.inputBuffer.get_iter_at_mark(mark1)
+                anchor = self.inputBuffer.create_child_anchor(iterStart)
+                self.input.add_child_at_anchor(img, anchor)
+
+                iter_start = self.inputBuffer.get_iter_at_mark(mark2)
+                self.inputBuffer.delete_mark(mark1)
+                self.inputBuffer.delete_mark(mark2)
+
+        for code in theme.getSmileysList():
+            replace_shortcuts(code, None)
 
         for code, filename in customEmo.list.iteritems():
-            iter_start = self.inputBuffer.get_start_iter()
-            iter_start.set_offset(self.parse_off)
-            while iter_start.forward_search(code,
-                                            gtk.TEXT_SEARCH_VISIBLE_ONLY):
-                iter_pos, iter_end = iter_start.forward_search(code,
-                    gtk.TEXT_SEARCH_VISIBLE_ONLY)
-
-                pixbuf = resizePixbuf(gtk.gdk.pixbuf_new_from_file(filename),
-                                      24, 24)
-
-                tag = gtk.TextTag()
-                tag.set_property('invisible', True)
-                tagtable = self.inputBuffer.get_tag_table()
-                tagtable.add(tag)
-                self.inputBuffer.apply_tag(tag, iter_pos, iter_end)
-
-                mark1 = self.inputBuffer.create_mark(None, iter_pos)
-                mark2 = self.inputBuffer.create_mark(None, iter_end)
-
-                img = gtk.Image()
-                img.set_from_pixbuf(pixbuf)
-                img.show()
-                img.shortcut = code
-
-                emos.append((img, mark1, mark2))
-                iter_start = iter_end
-
-        for emo in emos:
-            iterStart = self.inputBuffer.get_iter_at_mark(emo[1])
-            iterEnd = self.inputBuffer.get_iter_at_mark(emo[2])
-
-            self.inputBuffer.delete(iterStart, iterEnd)
-            iterStart = self.inputBuffer.get_iter_at_mark(emo[1])
-            #self.inputBuffer.insert_pixbuf(iterStart, emo[0])
-
-            anchor = self.inputBuffer.create_child_anchor(iterStart)
-
-            self.input.add_child_at_anchor(emo[0], anchor)
+            replace_shortcuts(code, filename)
 
         iter_off = self.inputBuffer.get_end_iter()
         if iter_off.inside_word() or iter_off.ends_word():
@@ -1162,13 +1154,18 @@ class InputWidget(gtk.HBox):
         else:
             pass
     
-    def getInputText(self, fast=False):
+    def getInputText(self, fast=False, selection=False):
         '''return the text in the input textview'''
-        iterStart, iterEnd = self.inputBuffer.get_bounds()
+        if selection:
+            iterStart, iterEnd = self.inputBuffer.get_selection_bounds()
+        else:
+            iterStart, iterEnd = self.inputBuffer.get_bounds()
         text = self.inputBuffer.get_slice(iterStart, iterEnd)
+
         if fast:
             return text
         emos = []
+
         #TODO: magic string '\xef\xbf\xbc'
         while iterStart.forward_search('\xef\xbf\xbc', \
             gtk.TEXT_SEARCH_VISIBLE_ONLY):
@@ -1180,7 +1177,6 @@ class InputWidget(gtk.HBox):
                 emos.append(anchor.get_widgets()[0].shortcut)
             elif anchor is None:
                 emos.append('')
-            #shortcut = iterPos.get_child_anchor().shortcut
 
             iterStart = iterEnd
 
@@ -1200,17 +1196,20 @@ class InputWidget(gtk.HBox):
         the message is a slash command ("^\/[^\/]" is confusing)
         Then, checks the last key pressed time, and if it's more
         than 5 seconds, send a typing message'''
-
+        
+        self.updateInputFormat()
+        
         if self.inputBuffer.get_start_iter().get_offset() < self.parse_off:
             self.parse_off = 0
         if self.id_timeout:
             gobject.source_remove(self.id_timeout)
 
         text = self.getInputText(True)
-        if len(text) > 5 and not (text[0] == '/' and text[1] != '/'):
+        if len(text) > 1 and not (text[0] == '/' and text[1] != '/'):
             self.id_timeout = gobject.timeout_add(200, self.transformEmo)
-        else:
-            self.updateInputFormat()
+
+        if not len(text) > 5:
+            #don't send start typing notification
             return
 
         # sents user typing notification
@@ -1225,7 +1224,14 @@ class InputWidget(gtk.HBox):
             except Exception , e:
                 print str(e)
 
-        self.updateInputFormat()
+    def _on_copy_clipboard(self, textview):
+        try:
+            start_sel, end_sel = self.inputBuffer.get_selection_bounds()
+            text = self.getInputText(False, True)
+            self.clipboard.set_text(text, len(text))
+            self.clipboard.store()
+        except ValueError: #if the user just press ctrl+c with nothing selected
+            return
 
     def applyAttrsToInput(self):
         '''apply the current attributes to the text in input'''
@@ -1413,7 +1419,7 @@ class ToolbarWidget(gtk.Toolbar):
         #font face
         separator = False
         if self.config.user['toolFontType']:
-            self.fontFace = gtk.ToolButton()
+            self.fontFace = gtk.ToolButton(label=_('Font selection'))
             if self.controller.theme.getImage('fontface'):
                 fontfaceicon = gtk.Image()
                 fontfaceicon.set_from_pixbuf(self.controller.theme.getImage('fontface'))
@@ -1429,7 +1435,7 @@ class ToolbarWidget(gtk.Toolbar):
 
         #font color
         if self.config.user['toolFontColor']:
-            self.fontColor = gtk.ToolButton()
+            self.fontColor = gtk.ToolButton(label=_('Font color selection'))
             if self.controller.theme.getImage('fontcolor'):
                 fontcoloricon = gtk.Image()
                 fontcoloricon.set_from_pixbuf(self.controller.theme.getImage('fontcolor'))
@@ -1445,8 +1451,7 @@ class ToolbarWidget(gtk.Toolbar):
 
         #font style button
         if self.config.user['toolFontStyle']:
-            self.fontStyleButton = gtk.ToolButton()
-            self.fontStyleButton.set_label(_('Fontstyle'))
+            self.fontStyleButton = gtk.ToolButton(label=_('Fontstyle'))
             if self.controller.theme.getImage('fontstyle'):
                 fonticon = gtk.Image()
                 fonticon.set_from_pixbuf(self.controller.theme.getImage('fontstyle'))
@@ -1494,8 +1499,7 @@ class ToolbarWidget(gtk.Toolbar):
 
         #invite button
         if self.config.user['toolInvite']:
-            self.inviteButton = gtk.ToolButton()
-            self.inviteButton.set_label(_('Invite'))
+            self.inviteButton = gtk.ToolButton(label=_('Invite'))
             if self.controller.theme.getImage('invite'):
                 inviteicon = gtk.Image()
                 inviteicon.set_from_pixbuf(self.controller.theme.getImage('invite'))
@@ -1512,8 +1516,7 @@ class ToolbarWidget(gtk.Toolbar):
 
         #send a file
         if self.config.user['toolSendFile']:
-            self.sendfileButton = gtk.ToolButton()
-            self.sendfileButton.set_label(_('Send File'))
+            self.sendfileButton = gtk.ToolButton(label=_('Send File'))
             if self.controller.theme.getImage('sendfile'):
                 imgsendfile = gtk.Image()
                 imgsendfile.set_from_pixbuf(self.controller.theme.getImage('sendfile'))
@@ -1653,7 +1656,7 @@ class ToolbarWidget(gtk.Toolbar):
             win.show_invite_dialog()
 
     def clearOutputText(self, *args):
-        self.parentUI.parentConversation.textBuffer.set_text('')
+        self.parentUI.textview.clear()
 
     def doNudge(self, *args):
         '''this method is called when the user click the nudge button'''
@@ -1671,7 +1674,7 @@ class ToolbarWidget(gtk.Toolbar):
         ret = self.parentUI.parentConversation.sendWebcam()
         if ret == 1:
             dialog.error(\
-                'You don\'t have libmimic, so you can\'t send or receive webcam') 
+                _('You don\'t have libmimic, so you can\'t send or receive webcam'))
             
     def inkDrawClicked(self, *args):
         if not self.controller or not self.controller.msn:
