@@ -44,11 +44,18 @@ class ConversationWindow(gtk.Window):
         self.notOpen = True
         self.minimized = False
 
-        self.width = self.config.user['convWindowWidth']
-        self.height = self.config.user['convWindowHeight']
-        self.set_default_size(self.width, self.height)
+        if not self.config.user['windows']:
+            self.geometry = self.config.user['convWindowGeometry']
+            self.parse_geometry(self.geometry)
+        else:
+            self.width = int(self.config.user['convWindowWidth'])
+            self.height = int(self.config.user['convWindowHeight'])
+            self.set_default_size(self.width, self.height)
+
+        if self.config.user['convMaximized']:
+            self.maximize()
+
         self.connect('size-allocate', self.on_size_alloc)
-        self.connect('window-state-event', self.setIconified)
 
         # accelerators
         accelGroup = gtk.AccelGroup()
@@ -105,6 +112,7 @@ class ConversationWindow(gtk.Window):
 
         self.connect('delete-event', self.close)
         self.connect('focus-in-event', self.on_focus_in_event)
+        self.connect('window-state-event', self.on_window_state_event)
         self.switchId = self.tabs.connect('switch-page', self.on_switch_page)
         self.showMenubarId = self.config.connect('change::showMenubar', \
             self.on_menubar_change)
@@ -133,6 +141,10 @@ class ConversationWindow(gtk.Window):
         self.unsetUrgency()
         self.conversation.ui.input.grabFocus()
 
+    def on_window_state_event(self, widget, event):
+        self.config.user['convMaximized'] = (event.new_window_state == gtk.gdk.WINDOW_STATE_MAXIMIZED)
+        self.minimized = (event.new_window_state == gtk.gdk.WINDOW_STATE_ICONIFIED)
+
     def on_size_alloc(self, widget, allocation):
         self.width = allocation.width
         self.height = allocation.height
@@ -180,16 +192,6 @@ class ConversationWindow(gtk.Window):
         if self.conversation.switchboard.firstUser == contact.email:
             self.set_icon(self.conversation.getWindowIcon())
 
-    #set minimized to true if the event is launched
-    #this may not always work because the window manager can do other thing
-    #instead of minimizing the window
-    #this should work almost always
-    def setIconified(self, widget, windowstateevent):
-        if windowstateevent.new_window_state == gtk.gdk.WINDOW_STATE_ICONIFIED:
-            self.minimized = True
-        else:
-            self.minimized = False
-
     def show_invite_dialog(self, conversation=None):
         '''show the invite dialog for conversation, if conversation is
         None, then the current conversation is used'''
@@ -408,7 +410,8 @@ class ConversationWindow(gtk.Window):
             activeTransfers = []
             for conv in self.conversations:
                 for tr in conv.transfers:
-                    activeTransfers.append(tr)        
+                    if tr.state not in (tr.RECEIVED, tr.FAILED):
+                        activeTransfers.append(tr)        
             if len(activeTransfers) > 0:
                 message = _("Transfers are happening, are you sure you want to cancel them?")
                 dialog.yes_no(message, self.close_win_confirmation, activeTransfers)
@@ -423,6 +426,7 @@ class ConversationWindow(gtk.Window):
             
     def close_win_for_real(self):
         ''' this method kills all the tabs (if present) and this very window'''
+        self.x, self.y = self.get_position()
         for conversation in self.conversations:
             conversation.setStatus('closed')
             conversation.setClosed(True)
@@ -436,6 +440,8 @@ class ConversationWindow(gtk.Window):
         self.conversations = []
         self.closed = True
 
+        self.geometry = '%dx%d+%d+%d' % (self.width,self.height,self.x,self.y)
+        self.controller.config.user['convWindowGeometry'] = self.geometry
         self.controller.config.user['convWindowWidth'] = self.width
         self.controller.config.user['convWindowHeight'] = self.height
 
@@ -470,9 +476,6 @@ class ConversationWindow(gtk.Window):
             try:
                 if self.controller.config.user['blinkTrayIcon']:
                     self.controller.trayIcon.tray.set_blinking(True)
-            except:
-                pass
-            try:
                 if self.controller.config.user['statusbarHighLight']:
                     self.set_urgency_hint(True)
             except:
@@ -481,11 +484,11 @@ class ConversationWindow(gtk.Window):
     def unsetUrgency(self):
         '''try to unset the urgency hint to the window and
         turn off tray icon blink'''
-
         try:
             self.set_urgency_hint(False)
             self.controller.trayIcon.tray.set_blinking(False)
             self.conversation.ui.update()
+            self.controller.emit('message-read')
         except:
             # errors related to getting disconnected don't really matter
             pass
