@@ -69,9 +69,9 @@ class MainMenu(gtk.MenuBar):
             statusMenuItem.set_submenu(statusMenu)
             fileMenu.add(statusMenuItem)
 
-            disconnect = self.newStockImageMenuItem(gtk.STOCK_DISCONNECT)
+            self.disconnectItem = self.newStockImageMenuItem(gtk.STOCK_DISCONNECT)
             fileMenu.add(gtk.SeparatorMenuItem())
-            fileMenu.add(disconnect)
+            fileMenu.add(self.disconnectItem)
         else:
             getliveMenuItem = self.newImageMenuItem(_('_New account'), \
                                                     gtk.STOCK_NEW)
@@ -299,7 +299,7 @@ class MainMenu(gtk.MenuBar):
         # We don't need this callbacks in login window,
         # because we didn't create this menu items
         if window_type == 'userlist':
-            disconnect.connect('activate', self.on_logout_activate)
+            self.disconnectItem.connect('activate', self.on_logout_activate)
             self.orderByGroup.connect('activate', self.on_order_changed)
             self.orderByStatus.connect('activate', self.on_order_changed)
 
@@ -560,7 +560,7 @@ class MainMenu(gtk.MenuBar):
         self.controller.contacts.unblock(self.userName)
 
     def on_delete_group_activate(self, *args):
-        self.controller.groups.remove(self.groupName)
+        self.controller.removeGroup(self.groupName)
 
     def on_rename_group_activate(self, *args):
         self.controller.groups.rename_dialog(self.groupName)
