@@ -24,7 +24,10 @@ import MainMenu
 import UserList
 import UserPanel
 import FilterEntry
+import dialog
 import emesenelib.common
+import pango
+import stock
 
 try:
     import gtk
@@ -63,13 +66,10 @@ class MainWindow(gtk.Window):
         self.set_title('emesene')
         self.set_role('main')
 
-        self.x = self.config.glob['mainWindowX']
-        self.y = self.config.glob['mainWindowY']
-
-        self.set_geometry_hints(self, -1, -1)
-        self.width = self.config.glob['mainWindowWidth']
-        self.height = self.config.glob['mainWindowHeight']
-        self.set_default_size(self.width , self.height)
+        self.geometry = self.config.glob['mainWindowGeometry']
+        self.parse_geometry(self.geometry)
+        self.on_size_alloc
+        self.x, self.y = self.get_position()
 
         self.connect('size-allocate', self.on_size_alloc)
 
@@ -126,11 +126,8 @@ class MainWindow(gtk.Window):
             except:
                 pass
 
-        self.controller.config.glob['mainWindowWidth'] = self.width
-        self.controller.config.glob['mainWindowHeight'] = self.height
-
-        self.controller.config.glob['mainWindowX'] = self.x
-        self.controller.config.glob['mainWindowY'] = self.y
+        self.geometry = '%dx%d+%d+%d' % (self.width,self.height,self.x,self.y)
+        self.controller.config.glob['mainWindowGeometry'] = self.geometry
 
     def quit(self, status = 0):
         '''close the window, and do all the things needed...'''
@@ -159,7 +156,12 @@ class MainWindow(gtk.Window):
         '''hide or close depending if we have trayicon'''
 
         if TrayIcon.disabled:
-            self.quit(0)
+            def remove_cb(response):
+                if response == stock.YES:
+                    self.quit(0)
+
+            message = _('This action will close emesene, continue?')
+            dialog.yes_no(message,remove_cb)
         else:
             self.hide()
 
@@ -235,12 +237,17 @@ class MainWindow(gtk.Window):
             self.vbox.pack_start(vbox2)
             self.vbox.pack_start(self.statusVBoxBottom, False, False)
 
-            if self.config.user['statusComboOnTop']:
-                self.statusVBoxTop.pack_start(self.statusCombo, False, False)
-                self.statusVBoxTop.show_all()
-            else:
+            statusPos = self.config.user['statusComboPos']
+            if statusPos == 0:
+                self.userPanel.show_status_icon()
+            elif statusPos == 2:
+                self.userPanel.hide_status_icon()
                 self.statusVBoxBottom.pack_start(self.statusCombo, False, False)
                 self.statusVBoxBottom.show_all()
+            else:
+                self.userPanel.hide_status_icon()
+                self.statusVBoxTop.pack_start(self.statusCombo, False, False)
+                self.statusVBoxTop.show_all()
 
             self.filterEntry.connect('filter-entry-lost-focus', self.lost_focus)
             vbox2.show_all()
@@ -267,20 +274,29 @@ class MainWindow(gtk.Window):
         self.update(self.controller)
 
         self.connect('delete-event' , self.hideOrClose)
+        self.connect('destroy-event', self.hideOrClose)
         self.emit('gui-build-done', guiType)
         self.connect('key-press-event', self.on_key_press)
 
 
-    def toggle_status_box(self, combo):      
-        self.statusCombo.get_parent().remove(self.statusCombo)
-        if combo.get_active():
-            self.statusVBoxTop.pack_start(self.statusCombo, False, False)
-            self.statusVBoxTop.show_all()
-            self.filterEntry.queue_draw()
+    def toggle_status_box(self, combo):
+        if self.statusCombo.get_parent():
+            self.statusCombo.get_parent().remove(self.statusCombo)
+        pos = combo.get_active()
+        if pos == 0:
+            self.userPanel.show_status_icon()
         else:
-            self.statusVBoxBottom.pack_start(self.statusCombo, False, False)
-            self.statusVBoxBottom.show_all()
-            self.filterEntry.queue_draw()
+            self.userPanel.hide_status_icon()
+            if pos == 1:
+                self.statusVBoxTop.pack_start(self.statusCombo, False, False)
+                if self.config.user['showStatusCombo']:
+                    self.statusVBoxTop.show_all()
+                self.filterEntry.queue_draw()
+            elif pos == 2:
+                self.statusVBoxBottom.pack_start(self.statusCombo, False, False)
+                if self.config.user['showStatusCombo']:
+                    self.statusVBoxBottom.show_all()
+                self.filterEntry.queue_draw()
 
     def lost_focus(self, widget):
         if self.filterEntry.entry.get_text() =='' and not self.config.user['showSearchEntry']:
@@ -344,7 +360,8 @@ class MainWindow(gtk.Window):
         if not self.config.user['showStatusCombo']:
             self.statusCombo.hide()
         else:
-            self.statusCombo.show()
+            if self.statusCombo.get_parent():
+                self.statusCombo.get_parent().show_all()
 
         if not self.config.user['showMenu']:
             self.menu.hide();
@@ -390,18 +407,18 @@ class MainWindow(gtk.Window):
 
     def initEventBox(self):
         self.eventBox = gtk.EventBox()
-        self.box = gtk.HBox(False, 0)
+        self.box = gtk.HBox()
         self.eventBox.add(self.box)
         self.label = gtk.Label()
-        self.label.set_line_wrap(True)
+        self.label.set_ellipsize(pango.ELLIPSIZE_END)
         self.image = gtk.Image()
         self.image.set_from_stock(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        self.box.pack_start(self.image, False, False, 5)
-        self.box.pack_start(self.label, True, True, 5)
+        self.box.pack_start(self.image, False, False, 3)
+        self.box.pack_start(self.label, True, True, 3)
         self.eventBox.connect("button-press-event", self.onClickNiceBar)
 
     #Info bar by default
-    def showNiceBar(self,message,color=None,image=gtk.STOCK_DIALOG_INFO):
+    def showNiceBar(self, message, color=None, image=gtk.STOCK_DIALOG_INFO):
         if message != None:
             if color == None:
                 color = self.controller.tooltipColor
