@@ -18,6 +18,7 @@
 
 import os
 import gtk
+import gobject
 
 disabled = False
 type_ = 'gtk'
@@ -41,7 +42,19 @@ if not gtk.check_version( 2, 10, 0 ) == None:
         except:
             print 'No tray icon library detected'
             disabled = True
-        
+'''
+##############################################################################
+#TODO:
+#- Find out how to set our nice icons
+#  because currently it does not work (i.e. after login, items aren't added)
+##############################################################################
+try:
+    import appindicator
+    type_ = 'indicator'
+    disabled = False
+except:
+    pass
+'''
 class TrayIcon:
     '''This class creates the tray icon notification - Pre-GTK 2.10'''
 
@@ -54,9 +67,11 @@ class TrayIcon:
         self.mainWindow = self.controller.mainWindow
         self.theme = self.controller.theme
         self.status = ''
-        if self.config.glob['disableTrayIcon']:
-            disabled = True
-        
+        self.tray = None
+        self.ind = None
+
+        disabled = self.config.glob['disableTrayIcon']
+
         try:
             if disabled:
                 pass
@@ -71,6 +86,15 @@ class TrayIcon:
                 
                 self.tray.connect( 'activate', self.on_activate )
                 self.tray.connect( 'popup-menu', self.on_popup_menu )
+            elif type_ == 'indicator':
+                self.ind = appindicator.Indicator("emesene", \
+                        "trayicon", appindicator.CATEGORY_APPLICATION_STATUS, \
+                        self.theme.path)
+                print self.ind.get_property("icon-theme-path")
+                self.ind.set_status(appindicator.STATUS_ACTIVE)
+                self.ind.set_attention_icon("lunch")
+                self.buildMenu()
+                self.ind.set_menu(self.menu)
             elif os.name == 'posix':
                 self.tray = egg.trayicon.TrayIcon('emesene')
                 self.buildTrayIconPosix()
@@ -88,8 +112,12 @@ class TrayIcon:
     def remove(self):
         '''remove the trayicon'''
 
-        if os.name == 'nt': 
+        if os.name == 'nt' and type_ != 'gtk': 
             self.win32ext.remove_notify_icon()
+        elif type_ == 'indicator':
+            self.ind.set_status(appindicator.STATUS_PASSIVE)
+        else:
+            self.tray.hide()
         
     def buildTrayIconPosix(self):
         '''Build the trayIcon for linux'''
@@ -103,7 +131,7 @@ class TrayIcon:
         self.eventBox.connect_object('button_press_event', self.iconClickPosix, self.eventBox)
 
         self.tooltips = gtk.Tooltips()
-        self.tooltips.set_tip(self.eventBox, 'Emesene')
+        self.tooltips.set_tip(self.eventBox, 'emesene')
         
         self.eventBox.add(self.image)
         self.tray.add(self.eventBox)
@@ -118,6 +146,11 @@ class TrayIcon:
             func = self.tray.set_from_pixbuf
         elif type_ == 'egg':
             func = self.image.set_from_pixbuf
+        elif type_ == 'indicator':
+            self.ind.set_icon(self.theme.statusToPixbuf(newUserStatus, False))
+            self.ind.set_menu(self.menu)
+            self.menu.show_all()
+            return
 
         if pixbuf == None:
             func(self.theme.statusToPixbuf(newUserStatus))
@@ -125,7 +158,7 @@ class TrayIcon:
             func(pixbuf)
 
         if self.controller.msn and self.controller.userEmail:
-            text = 'Emesene - ' + str(self.controller.userEmail)
+            text = 'emesene - ' + str(self.controller.userEmail)
             if type_ == 'egg':
                 self.tooltips.set_tip(self.eventBox, text)
             elif type_ == 'gtk':
@@ -168,8 +201,17 @@ class TrayIcon:
         self.menu.popup( None, None, position, button, activate_time, status_icon )
 
     def on_activate( self, status_icon ):
-        self.showHide()
-                
+        if self.tray.get_blinking():
+            conv = self.controller.conversationManager.newest_message_conv
+            conv_window = conv.parentConversationWindow
+
+            if conv_window.get_urgency_hint():
+                if conv_window.tabs.get_show_tabs():
+                    conv_window.showTab(conv_window.tabs.page_num(conv.ui))
+            conv_window.present()
+        else:
+            self.showHide()
+
     def buildMenu(self):
         '''Build the menu widget'''
 
@@ -178,13 +220,33 @@ class TrayIcon:
         menuItemQuit = gtk.ImageMenuItem( gtk.STOCK_QUIT )
         menuItemQuit.connect('activate', self.on_quit)
 
-        menuItemShowHide = gtk.ImageMenuItem( _("Hide/Show emesene") )
+        menuItemShowHide = gtk.MenuItem(_("Hide/Show emesene"))
         menuItemShowHide.connect('activate', self.showHide)
 
         self.menu.append(menuItemShowHide)
         self.menu.append(menuItemQuit)
+        if os.name == "nt":
+            self.timerID = None
+            self.menu.connect("leave-notify-event", self.start_timer_nt)
         self.menu.show_all()
-    
+
+    #I had to add all this "timerID != None" checks because the "source_remove"
+    #method doesn't stop the timeout_add function, am I doing something grown? -arielj
+    def start_timer_nt(self, menu, event):
+        if self.timerID == None:
+            self.timerID = gobject.timeout_add( 2000, self.popdownmenu )
+        self.deleteTimerID = self.menu.connect("motion-notify-event", self.remove_timer)
+
+    def remove_timer(self, menu, event):
+        if self.timerID != None:
+            gobject.source_remove(self.timerID)
+            self.timerID = None
+
+    def popdownmenu(self):
+        if self.timerID != None:
+            self.menu.popdown()
+        return False
+        
     def on_quit( self, menuitem):
         self.controller.quit( 0 )
     
@@ -198,7 +260,7 @@ class TrayIcon:
             self.mainWindow.show()
             
     def getNotifyObject( self ):
-        if not disabled and not type_ == 'gtk':
+        if not disabled and not type_ == 'gtk' and not type_ == 'indicator':
             return self.tray
         
-        return None
+        return None
\ No newline at end of file
