@@ -533,6 +533,10 @@ class UserList(gtk.TreeView):
     def getGroupLabel(self, group):
         '''return the pango string to format the group'''
         if self.showCountContact:
+            if group.id == 'nogroup':
+                return '<b>%s ( %d/%d )</b>' % (_('No group'), \
+                group.getOnlineUsersNumber(), group.getSize())
+
             return '<b>%s ( %d/%d )</b>' % (escape(group.name), \
                 group.getOnlineUsersNumber(), group.getSize())
         else:
