@@ -25,6 +25,10 @@ import paths
 import Avatar
 import urllib
 import Theme
+import thread
+import time
+
+import gc
 
 import abstract.stock as stock
 
@@ -407,6 +411,11 @@ def set_picture(controller, path_current, cache_path,
 
     def _on_hide(window):
         global _avatar_chooser
+        
+        if _avatar_chooser:
+            _avatar_chooser.stop_and_clear()
+            del _avatar_chooser
+                
         _avatar_chooser = None
 
     if not _avatar_chooser:
@@ -570,14 +579,21 @@ class AddBuddy(gtk.Window):
         self.later = gtk.Button()
         self.later.add(gtk.Label(_('Remind me later')))
         self.later.connect('clicked', self.cb_cancel)
-        self.profile = gtk.Button()
-        self.profile.add(gtk.Label(_('View profile')))
-        self.profile.connect('clicked', self.cb_profile)
         self.addbutton = gtk.Button(stock=gtk.STOCK_ADD)
         self.addbutton.connect('clicked', self.cb_add)
         self.bReject = gtk.Button()
         self.bReject.add(gtk.Label(_('Reject')))
         self.bReject.connect('clicked', self.cb_rej)
+        self.profile = gtk.Button()
+        self.profile.add(gtk.Label(_('View profile')))
+        self.profile.connect('clicked', self.cb_profile)
+        self.showDetails = False
+        self.bDetails = gtk.Button()
+        self.bDetails.add(gtk.Label(_('Details')))
+        self.bDetails.connect('clicked', self.cb_show_details)
+        self.bHideDetails = gtk.Button()
+        self.bHideDetails.add(gtk.Label(_('Hide details')))
+        self.bHideDetails.connect('clicked', self.cb_hide_details)
 
         ## packing
         self.add(self.vbox)
@@ -592,21 +608,88 @@ class AddBuddy(gtk.Window):
 
         self.hboxbuttons.pack_start(self.bReject, False, False)
         self.hboxbuttons.pack_start(self.later, False, False)
-        self.hboxbuttons.pack_start(self.profile, False, False)
-        self.hboxbuttons.pack_start(self.buttonbox)
-        self.buttonbox.pack_start(self.addbutton)
+        self.hboxbuttons.pack_start(self.addbutton, False, False)
+        self.hboxbuttons.pack_end(self.buttonbox)
+        self.buttonbox.pack_start(self.bDetails)
+
+    def cb_show_details(self, button):
+        #the widget that appears when the user clicks "details"
+        self.detailsSection = gtk.HBox(spacing=5)
+        genericAvatar = gtk.image_new_from_pixbuf(self.controller.theme.getImage('login'))
+        genericAvatar.set_size_request(96, 96)
+        labelAlias = gtk.Label(_("Alias"))
+        labelAlias_align = gtk.Alignment(0.0, 0.5)
+        labelAlias_align.add(labelAlias)
+        self.entryAlias = gtk.Entry()
+
+        group_label = gtk.Label(_("Group"))
+        groupsList = gtk.ListStore(gobject.TYPE_STRING)
+        self.groupComboEntry = gtk.ComboBoxEntry(groupsList, 0)
+        groupCompletion = gtk.EntryCompletion()
+        groupCompletion.set_model(groupsList)
+        self.groupComboEntry.get_children()[0].set_completion(groupCompletion)
+        groupCompletion.set_text_column(0)
+        group_label_align = gtk.Alignment(0.0, 0.5)
+        group_label_align.add(group_label)
+
+        #fill groups combo box
+        for i in self.controller.groups.groups.keys():
+            groupsList.append([i])
+
+        labelsVBox = gtk.VBox()
+        labelsVBox.pack_start(labelAlias_align)
+        labelsVBox.pack_start(group_label_align)
+
+        entriesVBox = gtk.VBox()
+        entriesVBox.pack_start(self.entryAlias)
+        entriesVBox.pack_start(self.groupComboEntry)
+
+        attributesHBox = gtk.HBox()
+        attributesHBox.pack_start(labelsVBox)
+        attributesHBox.pack_start(entriesVBox, True, True)
+
+        profileHBox = gtk.HButtonBox()
+        profileHBox.set_layout(gtk.BUTTONBOX_END)
+        profileHBox.pack_start(self.profile)
+
+        rightSideVBox = gtk.VBox()
+        rightSideVBox.pack_start(attributesHBox)
+        rightSideVBox.pack_start(profileHBox)
+
+        self.detailsSection.pack_start(genericAvatar)
+        self.detailsSection.pack_start(rightSideVBox, True, True)
+
+        self.vbox.pack_end(self.detailsSection)
+        self.detailsSection.show_all()
+
+        self.buttonbox.remove(self.bDetails)
+        self.buttonbox.pack_start(self.bHideDetails)
+        self.profile.show_all()
+        self.bHideDetails.show_all()
+        self.showDetails = True
+
+    def cb_hide_details(self, button):
+        self.profile.get_parent().remove(self.profile)
+        self.vbox.remove(self.detailsSection)
+        self.detailsSection.destroy()
+        self.buttonbox.remove(self.bHideDetails)
+        self.buttonbox.pack_start(self.bDetails)
+        self.bDetails.show_all()
+        self.showDetails = False
 
     def _buildpages(self):
         '''Builds hboxpages, that is a bit complex to include in __init__'''
         hboxpages = gtk.HBox()
 
-        arrowleft = Widgets.TinyArrow(gtk.ARROW_LEFT)
+        arrowleft = gtk.Arrow(gtk.ARROW_LEFT,gtk.SHADOW_NONE)
+        arrowleft.set_size_request(-1,15)
         self.buttonleft = gtk.Button()
         self.buttonleft.set_relief(gtk.RELIEF_NONE)
         self.buttonleft.add(arrowleft)
         self.buttonleft.connect('clicked', self.switchmail, -1)
 
-        arrowright = Widgets.TinyArrow(gtk.ARROW_RIGHT)
+        arrowright = gtk.Arrow(gtk.ARROW_RIGHT,gtk.SHADOW_NONE)
+        arrowright.set_size_request(-1,15)
         self.buttonright = gtk.Button()
         self.buttonright.set_relief(gtk.RELIEF_NONE)
         self.buttonright.add(arrowright)
@@ -654,6 +737,10 @@ class AddBuddy(gtk.Window):
         self.currentpage.set_markup('<b>(%s/%s)</b>' % \
             (self.pointer + 1, len(self.mails)))
 
+        if self.showDetails:
+            self.entryAlias.set_text("")
+            self.groupComboEntry.child.set_text("")
+
     def switchmail(self, button, order):
         '''Moves the mail pointer +1 or -1'''
         if (self.pointer + order) >= 0:
@@ -689,9 +776,22 @@ class AddBuddy(gtk.Window):
     def cb_add(self, button):
         '''Callback when the add button is clicked'''
         mail, nick = self.mails[self.pointer]
-        self.controller.contacts.add(mail, '')
+        group = ''
+        alias = ''
+        if self.showDetails:
+            group = self.groupComboEntry.get_children()[0].get_text()
+            if group and not group in self.controller.groups.groups.keys():
+                    self.controller.groups.add(group)
+            alias = self.entryAlias.get_text()
+
+        self.controller.contacts.add(mail, group, *(self.delayedAlias, mail, alias))
+#        self.controller.contacts.add(mail, group)
         self.cb_cancel(None)
-        
+
+    def delayedAlias(self, account, alias):
+        self.controller.contacts.set_alias(account, alias)
+        return False
+
     def cb_rej(self, button):
         mail, nick = self.mails[self.pointer]
         self.controller.contacts.remove_from_pending_list(mail)
@@ -721,11 +821,11 @@ class Profile(gtk.Window):
         self.nickLabel=gtk.Label(_('Nick:'))
         self.nickLabel.set_alignment(0.0,0.5)
         self.nickEntry=gtk.Entry()
-        self.nickEntry.set_text(nick)
+        self.nickEntry.set_text(self.nick)
         self.psmLabel=gtk.Label(_('Personal Message:'))
         self.psmLabel.set_alignment(0.0,0.5)
         self.psmEntry=gtk.Entry()
-        self.psmEntry.set_text(psm)
+        self.psmEntry.set_text(self.psm)
         self.vbox = gtk.VBox()
         self.vbox.add(self.nickLabel)
         self.vbox.add(self.nickEntry)
@@ -768,6 +868,8 @@ class Profile(gtk.Window):
         self.nickEntry.connect('activate', self.on_accept)
         self.psmEntry.connect('activate', self.on_accept)
         self.controller.connect('avatar-changed', self.updateAvatar)
+        self.controller.msn.connect('self-personal-message-changed', self.update_pm_entry)
+        self.controller.msn.connect('self-nick-changed', self.update_nick_entry)
 
         #add everything to the window and show it
         self.add(self.vbox2)
@@ -784,6 +886,12 @@ class Profile(gtk.Window):
             pixbuf = gtk.gdk.pixbuf_new_from_file(avatarPath)
             self.currentAvatar.set_from_pixbuf(pixbuf)
 
+    def update_nick_entry(self, msnp, oldNick, newNick):
+        self.nickEntry.set_text(newNick)
+
+    def update_pm_entry(self, msnp, user, pm):
+        self.psmEntry.set_text(pm)
+
     #this method show the avatar chooser dialog and saves the new avatar if any
     #this method does not change the actual avatar, just the dialog's avatar
     def choose_picture(self, widget, event):
@@ -819,6 +927,133 @@ class Profile(gtk.Window):
         self.destroy()
         self.response_cb(stock.CLOSE, '', '', '')
 
+# Class that holds the iconview from the avatar chooser dialog
+class IconView(gtk.HBox):
+    def __init__(self, label, path_list, avatar_chooser):
+        gtk.HBox.__init__(self)
+        self.set_spacing(4)
+        self.chooser = avatar_chooser
+        self.model = gtk.ListStore(gtk.gdk.Pixbuf, str)   
+        self.iconview = gtk.IconView(self.model)
+        self.iconview.enable_model_drag_dest([('text/uri-list', 0, 0)], gtk.gdk.ACTION_DEFAULT | gtk.gdk.ACTION_COPY)
+        self.iconview.connect("drag-data-received", self._drag_data_received)
+        self.iconview.set_pixbuf_column(0)
+        self.iconview.connect("item-activated", self._on_icon_activated)
+        self.iconview.connect("button_press_event", self.pop_up)
+
+        self.label = gtk.Label(label)
+        
+        self.scroll = gtk.ScrolledWindow()
+        self.scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.scroll.set_shadow_type(gtk.SHADOW_IN)
+        self.scroll.add(self.iconview)
+        self.pack_start(self.scroll, True, True)
+
+        self.STOP = False
+        # Start a new thread to fill the iconview with images from path_list
+        thread.start_new_thread(self.fill, (path_list,))
+
+    def stop_and_clear(self):
+        self.STOP = True
+        self.model.clear()
+
+    def fill(self, path_list):
+        '''fill the IconView with avatars from the list of pictures'''
+        for search_path in path_list:
+            if os.path.exists(search_path):
+                for path in os.listdir(search_path):
+                    name = os.path.splitext(path)[0]
+                    if self.STOP:
+                        return False
+                    if not name.endswith('_thumb') and not path.endswith('tmp') \
+                       and not path.endswith('xml') and not path.endswith('db'):
+                        gtk.gdk.threads_enter()
+                        self.add_picture(os.path.join(search_path, path))
+                        # make update the iconview
+                        self.iconview.queue_draw()
+                        gtk.gdk.threads_leave()        
+                        
+                        # give some time to the main thread (for GUI updates)
+                        time.sleep(0.001)
+        # Force Garbage Collector to tidy objects
+        # see http://faq.pygtk.org/index.py?req=show&file=faq08.004.htp
+        gc.collect()
+    
+    def pop_up(self, iconview, event):
+        if event.button == 3 and self.label.get_text() != _('System pictures'):
+            path = self.iconview.get_path_at_pos(event.x, event.y)
+            if path != None:
+                self.iconview.select_path(path)
+                remove_menu = gtk.Menu()
+                remove_item = gtk.ImageMenuItem(_('Delete'))
+                remove_item.set_image(gtk.image_new_from_stock(gtk.STOCK_REMOVE, gtk.ICON_SIZE_MENU))
+                remove_item.connect('activate', self.chooser._on_remove)
+                remove_menu.append(remove_item)
+                remove_menu.popup(None, None, None, event.button, event.time)
+                remove_menu.show_all()
+
+    def _drag_data_received(self, treeview, context, x, y, selection, info, timestamp):
+        '''method called on an image dragged to the view'''
+        urls = selection.data.split('\n')
+        for url in urls:
+            path = url.replace('file://', '')
+            path = path.replace('\r', '')
+
+            # the '\x00' value makes an error
+            path = path.replace(chr(0), '')
+
+            # this seems to be an error on ntpath but we take care :S
+            try:
+                if os.path.exists(path):
+                    self.add_picture(path)
+            except TypeError, e:
+                error(_("Could not add picture:\n %s") % (str(e),))
+
+    def add_picture(self, path):
+        '''Adds an avatar into the IconView'''
+        try:
+            if os.path.exists(path) and os.access(path, os.R_OK)\
+                    and not self.is_in_view(path):
+                try:
+                    pixbuf = gtk.gdk.pixbuf_new_from_file(path)
+                except:
+                    try:
+                        os.remove(path)
+                    except:
+                        pass
+                    return
+ 
+                # On nt images are 128x128 (48x48 on xp)
+                # On kde, images are 64x64
+                if (self.label.get_text() == _('System pictures') or \
+                 self.label.get_text() == _('Contact pictures')) and \
+                 (pixbuf.get_width() != 96 or pixbuf.get_height() != 96):
+                    pixbuf = pixbuf.scale_simple(96, 96, gtk.gdk.INTERP_BILINEAR)
+
+                if self.model != None and not self.STOP:
+                    self.model.append([pixbuf, path])
+                    # Esplicitely delete gtkpixbuf
+                    # see http://faq.pygtk.org/index.py?req=show&file=faq08.004.htp
+                    del pixbuf
+            else:
+                print path, 'not readable'
+        except gobject.GError:
+            print "image at %s could not be loaded" % path
+
+    def is_in_view(self, filename):
+        '''return True if filename already on the iconview'''
+        if os.name != 'nt' and not self.STOP:
+            for (pixbuf, path) in self.model:
+                if os.path.samefile(filename, path):
+                    return True
+        return False
+
+    def _on_icon_activated(self, *args):
+        '''method called when a picture is double clicked'''
+        self.chooser._on_accept(None)
+    
+    def get_selected_items(self):
+        return self.iconview.get_selected_items()
 
 class AvatarChooser(gtk.Window):
     '''A dialog to choose an avatar'''
@@ -836,24 +1071,28 @@ class AvatarChooser(gtk.Window):
         self.cache_path = cache_path
 
         self.set_title(_("Avatar chooser"))
-        self.set_default_size(602, 400)
+        self.set_default_size(640, 400)
         self.set_border_width(4)
         self.set_position(gtk.WIN_POS_CENTER)
         self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
 
-        self.model = gtk.ListStore(gtk.gdk.Pixbuf, str)
+        faces_paths = []
+        if os.name == 'nt':
+            appDataFolder = os.path.split(os.environ['APPDATA'])[1]
+            faces_path = os.path.join(os.environ['ALLUSERSPROFILE'], appDataFolder, \
+                         "Microsoft", "User Account Pictures", "Default Pictures")
+            #little hack to fix problems with encoding
+            unicodepath=u"%s" % faces_path
+            faces_paths = [unicodepath]
+        else:
+            faces_paths = ['/usr/share/kde/apps/faces',\
+                           '/usr/share/kde4/apps/kdm/pics/users', \
+                           '/usr/share/pixmaps/faces']
 
-        self.view = gtk.IconView(self.model)
-        self.view.enable_model_drag_dest([('text/uri-list', 0, 0)], gtk.gdk.ACTION_DEFAULT | gtk.gdk.ACTION_COPY)
-        self.view.connect("drag-data-received", self._drag_data_received)
-
-        self.view.set_pixbuf_column(0)
-        self.view.connect("item-activated", self._on_icon_activated)
-
-        scroll = gtk.ScrolledWindow()
-        scroll.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
-        scroll.set_shadow_type(gtk.SHADOW_IN)
-        scroll.add(self.view)
+        self.iconViews = []
+        self.iconViews.append( IconView(_('Used'), [cache_path], self) )
+        self.iconViews.append( IconView(_('System pictures'), faces_paths, self) )
+        self.iconViews.append( IconView(_('Contact pictures'),[self.controller.config.getCachePath()], self) )
 
         vbox = gtk.VBox(spacing=4)
         side_vbox = gtk.VBox(spacing=4)
@@ -868,16 +1107,17 @@ class AvatarChooser(gtk.Window):
         vbbox.set_layout(gtk.BUTTONBOX_START)
 
         b_clear = gtk.Button(_("No picture"))
-        b_add = gtk.Button(stock=gtk.STOCK_ADD)
-        b_remove = gtk.Button(stock=gtk.STOCK_REMOVE)
-        b_remove_all = gtk.Button(_("Remove all"))
+        self.b_add = gtk.Button(stock=gtk.STOCK_ADD)
+        self.b_remove = gtk.Button(stock=gtk.STOCK_REMOVE)
+        self.b_remove_all = gtk.Button(_("Remove all"))
         b_accept = gtk.Button(stock=gtk.STOCK_OK)
         b_cancel = gtk.Button(stock=gtk.STOCK_CANCEL)
+        b_accept.set_sensitive(False)
 
         b_clear.connect('clicked', self._on_clear)
-        b_add.connect('clicked', self._on_add)
-        b_remove.connect('clicked', self._on_remove)
-        b_remove_all.connect('clicked', self._on_remove_all)
+        self.b_add.connect('clicked', self._on_add)
+        self.b_remove.connect('clicked', self._on_remove)
+        self.b_remove_all.connect('clicked', self._on_remove_all)
         b_accept.connect('clicked', self._on_accept)
         b_cancel.connect('clicked', self._on_cancel)
         self.connect('delete-event', self._on_close)
@@ -892,14 +1132,34 @@ class AvatarChooser(gtk.Window):
         hbbox.pack_start(b_cancel, False)
         hbbox.pack_start(b_accept, False)
 
-        vbbox.pack_start(b_add, False)
-        vbbox.pack_start(b_remove, False)
-        vbbox.pack_start(b_remove_all, False)
+        vbbox.pack_start(self.b_add, False)
+        vbbox.pack_start(self.b_remove, False)
+        vbbox.pack_start(self.b_remove_all, False)
 
         side_vbox.pack_start(frame_current, False)
         side_vbox.pack_start(vbbox)
 
-        hbox.pack_start(scroll, True, True)
+        self.notebook = gtk.Notebook()
+        self.notebook.set_show_tabs(True)
+        
+        for view in self.iconViews:
+            self.notebook.append_page(view, view.label)
+            view.iconview.connect("selection-changed",\
+                                self.onSelectionChanged, b_accept)
+        self.notebook.connect("switch-page", self._on_tab_changed, b_accept)
+
+        #close dialog at logout
+        self.controller.msn.connect('user-disconnected', self._on_close)
+        self.controller.msn.connect('connection-problem', self._on_close)
+        self.controller.msn.connect('connection-closed', self._on_close)
+        self.controller.msn.connect('disconnected', self._on_close)
+        self.controller.mainWindow.menu.disconnectItem.connect(\
+                                    'button-release-event', self._on_close)
+        if self.controller.trayIcon != None and \
+           self.controller.trayDisconnect != None:
+            self.controller.trayDisconnect.connect('activate', self._on_close)
+
+        hbox.pack_start(self.notebook, True, True)
         hbox.pack_start(side_vbox, False, False)
 
         vbox.pack_start(hbox, True, True)
@@ -908,9 +1168,38 @@ class AvatarChooser(gtk.Window):
         vbox.show_all()
         self.add(vbox)
 
-        self.fill()
         self.set_current_picture(picture_path)
 
+    def onSelectionChanged(self, iconView, accept_button):
+        selected = iconView.get_selected_items()
+        if len(selected) == 0:
+            accept_button.set_sensitive(False)
+        else:
+            accept_button.set_sensitive(True)
+        
+    def stop_and_clear(self):
+        for view in self.iconViews:
+            view.stop_and_clear()
+        # Force Garbage Collector to tidy objects
+        # see http://faq.pygtk.org/index.py?req=show&file=faq08.004.htp
+        gc.collect()
+
+    def _on_tab_changed(self, notebook, page, page_num, b_accept):
+        view = self.iconViews[page_num]
+        if view.label.get_text() == _('System pictures'):
+            self.b_add.set_sensitive(False)
+            self.b_remove.set_sensitive(False)
+            self.b_remove_all.set_sensitive(False)
+        elif view.label.get_text() == _('Contact pictures'):
+            self.b_add.set_sensitive(False)
+            self.b_remove.set_sensitive(True)
+            self.b_remove_all.set_sensitive(True)
+        else:
+            self.b_add.set_sensitive(True)
+            self.b_remove.set_sensitive(True)
+            self.b_remove_all.set_sensitive(True)
+        self.onSelectionChanged(view.iconview, b_accept)
+
     def set_current_picture(self, path):
         '''set the current picture on the frame'''
         if os.path.exists(path):
@@ -922,21 +1211,24 @@ class AvatarChooser(gtk.Window):
         iter = self.get_selected_iter()
 
         if iter:
-            return self.model[iter]
+            view = self.iconViews[self.notebook.get_current_page()]
+            return view.model[iter]
 
         return None
 
     def get_selected_iter(self):
         '''return the selected iter or None'''
-        if len(self.view.get_selected_items()) > 0:
-            item = self.view.get_selected_items()[0]
-            return self.model.get_iter(item)
+        view = self.iconViews[self.notebook.get_current_page()]
+        if len(view.get_selected_items()) > 0:
+            item = view.get_selected_items()[0]
+            return view.model.get_iter(item)
 
         return None
 
     def get_iter_from_filename(self, path):
         '''return the iter of a filename or None'''
-        for row in self.model:
+        view = self.iconViews[self.notebook.get_current_page()]
+        for row in view.model:
             (pixbuf, filename) = row
 
             if self.samefile(filename, path):
@@ -955,50 +1247,20 @@ class AvatarChooser(gtk.Window):
            os.path.samefile(path1, path2)) or \
            (path1.lower() == path2.lower()))
 
-    def fill(self):
-        '''fill the IconView with avatars from the list of pictures'''
-
-        for path in os.listdir(self.cache_path):
-            if not os.path.splitext(path)[0].endswith('_thumb'):
-                self.add_picture(os.path.join(self.cache_path, path))
-
-    def is_in_view(self, filename):
-        '''return True if filename already on the iconview'''
-
-        if os.name == 'nt':
-            # nt doesn't include os.path.samefile
-            return False
-
-        for (pixbuf, path) in self.model:
-            if os.path.samefile(filename, path):
-                return True
-
-        return False
-
-
-    def add_picture(self, path):
-        '''Adds an avatar into the IconView'''
-        try:
-            if os.path.exists(path) and os.access(path, os.R_OK)\
-                    and not self.is_in_view(path):
-                pixbuf = gtk.gdk.pixbuf_new_from_file(path)
-
-                self.model.append([pixbuf, path])
-            else:
-                print path, 'not readable'
-        except gobject.GError:
-            print 'image at %s could not be loaded'
-            print gobject.GError
-
     def remove(self, path):
         '''remove the avatar in path'''
-        del self.model[self.get_iter_from_filename(path)]
+        view = self.iconViews[self.notebook.get_current_page()]
+        del view.model[self.get_iter_from_filename(path)]
         try:
             os.remove(path)
+        except Exception, e:
+            print "could not remove", path
+            
+        try:
             parts = os.path.splitext(path)
             os.remove(parts[0] + "_thumb" + parts[1])
         except Exception, e:
-            print "could not remove", path
+            pass
 
     def remove_selected(self):
         '''Removes avatar from a TreeIter'''
@@ -1010,46 +1272,26 @@ class AvatarChooser(gtk.Window):
 
     def remove_all(self):
         '''remove all the items on the view'''
-        for (pixbuf, path) in self.model:
+        view = self.iconViews[self.notebook.get_current_page()]
+        for (pixbuf, path) in view.model:
             self.remove(path)
 
-        self.model.clear()
-
-    def _drag_data_received(self, treeview, context, x, y, selection, info,
-                             timestamp):
-        '''method called on an image dragged to the view'''
-        urls = selection.data.split('\n')
-        for url in urls:
-            path = url.replace('file://', '')
-            path = path.replace('\r', '')
-
-            # the '\x00' value makes an error
-            path = path.replace(chr(0), '')
-
-            # this seems to be an error on ntpath but we take care :S
-            try:
-                if os.path.exists(path):
-                    self.add_picture(path)
-            except TypeError, e:
-                error(_("Could not add picture:\n %s") % (str(e),))
-
-    def _on_icon_activated(self, *args):
-        '''method called when a picture is double clicked'''
-        self._on_accept(None)
+        view.model.clear()
 
     def _on_add(self, button):
         '''called when the user select the add button'''
         def _on_image_selected(response, path):
             '''method called when an image is selected'''
-            if response == stock.ACCEPT:
+            if response == gtk.RESPONSE_ACCEPT:
                 try:
                     av = Avatar.Avatar(self.controller, path, self.cache_path, resizeDialog=True)
                     filename = av.getImagePath()
-                    self.add_picture(av.getImagePath())
+                    view = self.iconViews[self.notebook.get_current_page()] 
+                    view.add_picture(av.getImagePath())
                 except Exception, e:
                     error(str(e))
 
-        ImageChooser(paths.HOME_DIR, _on_image_selected).show()
+        ImageChooser(paths.HOME_DIR, _on_image_selected).run()
 
     def _on_remove(self, event):
         '''Removes the selected avatar'''
@@ -1088,7 +1330,7 @@ class AvatarChooser(gtk.Window):
         self.hide()
         self.response_cb(stock.CLEAR, '')
 
-    def _on_close(self, window, event):
+    def _on_close(self, *args):
         '''called when the user click on close'''
         self.hide()
         self.response_cb(stock.CLOSE, '')
@@ -1098,26 +1340,24 @@ class AvatarChooser(gtk.Window):
         if event.keyval == gtk.keysyms.Delete:
             self.remove_selected()
 
-class ImageChooser(gtk.Window):
+class ImageChooser(gtk.FileChooserDialog):
     '''a class to select images'''
 
     def __init__(self, path, response_cb):
         '''class constructor, path is the directory where the
         dialog opens'''
-        gtk.Window.__init__(self)
+        gtk.FileChooserDialog.__init__(self, _("Image Chooser"), \
+                    parent=None, action=gtk.FILE_CHOOSER_ACTION_OPEN)
 
         self.response_cb = response_cb
 
-        self.set_title(_("Image Chooser"))
         self.set_default_size(600, 400)
         self.set_border_width(4)
         self.set_position(gtk.WIN_POS_CENTER)
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
 
-        self.vbox = gtk.VBox(spacing=4)
+        self.vbox.set_spacing(4)
 
-        self.file_chooser = gtk.FileChooserWidget()
-        self.file_chooser.set_current_folder(path)
+        self.set_current_folder(path)
 
         hbbox = gtk.HButtonBox()
         hbbox.set_spacing(4)
@@ -1129,18 +1369,14 @@ class ImageChooser(gtk.Window):
         b_accept.connect('clicked', self._on_accept)
         b_cancel.connect('clicked', self._on_cancel)
         self.connect('delete-event', self._on_close)
-        self.file_chooser.connect("file-activated",self._on_accept)
+        self.connect("file-activated",self._on_accept)
 
         hbbox.pack_start(b_cancel, False)
         hbbox.pack_start(b_accept, False)
 
-        vbox = gtk.VBox()
-        self.vbox.pack_start(self.file_chooser, True, True)
+        self.vbox.pack_end(hbbox, False)
 
-        vbox.add(self.vbox)
-        vbox.pack_start(hbbox, False)
-        self.add(vbox)
-        vbox.show_all()
+        self.show_all()
 
         self._add_filters()
         self._add_preview()
@@ -1179,12 +1415,12 @@ class ImageChooser(gtk.Window):
             filters.append(filter)
 
 
-        self.file_chooser.add_filter(all_files)
-        self.file_chooser.add_filter(all_images)
-        self.file_chooser.set_filter(all_images)
+        self.add_filter(all_files)
+        self.add_filter(all_images)
+        self.set_filter(all_images)
 
         for filter in filters:
-            self.file_chooser.add_filter(filter)
+            self.add_filter(filter)
 
     def _add_preview(self):
         '''
@@ -1195,29 +1431,29 @@ class ImageChooser(gtk.Window):
         self.image.set_size_request(128, 128)
         self.image.show()
 
-        self.file_chooser.set_preview_widget(self.image)
-        self.file_chooser.set_preview_widget_active(True)
+        self.set_preview_widget(self.image)
+        self.set_preview_widget_active(True)
 
-        self.file_chooser.connect('update-preview', self._on_update_preview)
+        self.connect('selection-changed', self._on_update_preview)
 
     def _on_accept(self, button):
         '''method called when the user clicks the button'''
         filename = get_filename(self)
         if os.path.isfile(filename):
             self.hide()
-            self.response_cb(stock.ACCEPT, filename)
+            self.response_cb(gtk.RESPONSE_ACCEPT, filename)
         else:
             error(_("No picture selected"))
 
     def _on_cancel(self, button):
         '''method called when the user clicks the button'''
         self.hide()
-        self.response_cb(stock.CANCEL, get_filename(self))
+        self.response_cb(gtk.RESPONSE_CANCEL, get_filename(self))
 
     def _on_close(self, window, event):
         '''called when the user click on close'''
         self.hide()
-        self.response_cb(stock.CLOSE, get_filename(self))
+        self.response_cb(gtk.RESPONSE_CLOSE, get_filename(self))
 
     def _on_update_preview(self, filechooser):
         '''
@@ -1256,10 +1492,10 @@ class CEChooser(ImageChooser):
         self.response_cb = response_cb
 
         label = gtk.Label(_("Shortcut"))
-        self.shortcut = gtk.Entry()
+        self.shortcut = gtk.Entry(7)
         self.combo = gtk.combo_box_new_text()
 
-        tooltip_t = _("You can add an emoticon also by entering the url of a png/gif image.")
+        tooltip_t = _("You can add an emoticon also by entering the url an image (url must start with www. or http:// and finish with a file extension of the supported files).")
 
         labelurl = gtk.Label(_("Or enter an image url"))
         labelurl.set_tooltip_text(tooltip_t)
@@ -1300,9 +1536,14 @@ class CEChooser(ImageChooser):
         size = self.combo.get_model().get_value(self.combo.get_active_iter(), 0)
 
         URL = self.url.get_text()
-        if URL[:4] == 'www.':
-            	    URL = 'http://'+URL
-        ENDEXT = URL.endswith('.gif') or URL.endswith('.png')
+        if URL.startswith('www.'):
+            URL = 'http://'+URL
+
+        ENDEXT = False
+        for format in gtk.gdk.pixbuf_get_formats():
+            for ext in format['extensions']:
+                ENDEXT = ENDEXT or URL.endswith('.'+ext)
+
         if URL.startswith('http://') and ENDEXT == True:
             if not shortcut:
                 error(_("Empty shortcut"))
@@ -1345,7 +1586,7 @@ class CEChooser(ImageChooser):
 
 def get_filename(self):
     '''Shortcut to get a properly-encoded filename from a file chooser'''
-    filename = self.file_chooser.get_filename()
+    filename = self.get_filename()
     if filename and gtk.gtk_version >= (2, 10, 0):
         return gobject.filename_display_name(filename)
     else:
@@ -1353,7 +1594,7 @@ def get_filename(self):
 
 def get_preview_filename(self):
     '''Shortcut to get a properly-encoded preview filename'''
-    filename = self.file_chooser.get_preview_filename()
+    filename = self.get_filename()
     if filename and gtk.gtk_version >= (2, 10, 0):
         return gobject.filename_display_name(filename)
     else:
