@@ -18,6 +18,8 @@
 
 import gobject
 import urllib
+import base64
+import os
 
 import ContactData
 import soap.manager
@@ -78,8 +80,10 @@ class ProfileManager(gobject.GObject):
             gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT)),
     }
 
-    def __init__(self):
+    def __init__(self, config):
         gobject.GObject.__init__(self)
+        self.config = config
+        self.profile_retrieved = False
 
     def onGetMembershipList(self, response):
         '''method called when we receive the membership list'''
@@ -107,22 +111,172 @@ class ProfileManager(gobject.GObject):
             return False
 
     def onGetProfile(self, response):
-        if response.status[0] != 200:
-            self.affinityCache = ''
-            self.rid = ''
+        #print response.body
+        if response.status[0] != 200 or \
+           response.body.find('<ExpressionProfile>') == -1:
+            if self.triedCreatingProfile:
+                # we already tried, but failed.. :(
+                self.affinityCache = ''
+                self.rid = ''
+            else:
+                #user doesn't have a roaming profile, try create one.
+                soap.requests.create_profile(self.proxy, self.reRequestProfile)
             return
+
         try:
             nick = response.body.split('</DisplayName>')[0].split('<DisplayName>')[1]
-        except: # yes, someone doesn't have a nickname, it seems --c10ud
-            nick = ''
-        try: # okay, this uglyness is not pablo's fault, i confess --c10ud
-            pm = response.body.split('</PersonalStatus>')[0].split('<PersonalStatus>')[1]
+            nick = common.unescape(nick)
         except:
+            nick = ''
+
+        try:
+            pm = response.body.split('</PersonalStatus>')[0].split('<PersonalStatus>')[1]
+            pm = common.unescape(pm)
+        except: 
             pm = ''        
+            
+        try:
+            dpurl = response.body.split('</StaticUserTilePublicURL>')[0].split('<StaticUserTilePublicURL>')[1]
+            photo = response.body.split('</Photo>')[0].split('<Photo>')[1]
+            self.dpid = photo.split('</ResourceID>')[0].split('<ResourceID>')[1]
+            name = photo.split('</Name>')[0].split('Name>')[1]
+        except:
+            dpurl = ''
+            self.dpid = ''
+
+        if dpurl != '' and name != self.config.glob['Id']:         
+            gobject.idle_add(self.getPicture, dpurl)
+
         self.changeNick(nick, initial=True)
         self.changePersonalMessage(pm)
         self.affinityCache = response.body.split('</CacheKey>')[0].split('<CacheKey>')[1]
-        self.rid = response.body.split('</ResourceID>')[0].split('<ResourceID>')[1]
+        expression_profile = response.body.split('</ExpressionProfile>')[0].split('<ExpressionProfile>')[1]
+        self.rid = expression_profile.split('</ResourceID>')[0].split('<ResourceID>')[1]
+        self.profile_retrieved = True
+    
+    def updateDisplayPicture(self):
+        if self.affinityCache != '':
+            if self.dpid != '':
+                soap.requests.delete_relationship1(self.proxy, self.affinityCache, \
+                    self.dpid, self.cid, self.onDeleteRelationship1)
+            else:
+                soap.requests.update_dp(self.proxy, self.affinityCache, \
+                    self.cid, self.config.glob['Id'], 'png', \
+                    base64.b64encode(self.msnobj.data), self.onCreateRelationships)
+
+    def getPicture(self, url):
+        import httplib
+        import socket
+        
+        hdrs = {"User-Agent": "MSN Explorer/9.0 (MSN 8.0; TmstmpExt)",}
+        
+        if self.proxy and self.proxy.host != '':
+            proxy_connect = 'CONNECT %s:%s HTTP/1.0\r\n'%(self.proxy.host, self.proxy.port)
+            user_agent = 'User-Agent: python\r\n'
+            if self.proxy.user:
+                common.debug('>>> using proxy auth user: '+self.proxy.user)
+                # setup basic authentication
+                user_pass = base64.encodestring(self.proxy.user+':'+self.proxy.password).replace('\n','')
+                proxy_authorization = 'Proxy-authorization: Basic '+user_pass+'\r\n'
+                proxy_pieces = proxy_connect+proxy_authorization+user_agent+'\r\n'
+            else:
+                proxy_pieces = proxy_connect+user_agent+'\r\n'
+            # now connect, very simple recv and error checking
+            proxy = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
+            proxy.connect((self.proxy.host,int(self.proxy.port)))
+            proxy.sendall(proxy_pieces)
+            response = proxy.recv(8192) 
+            status=response.split()[1]
+            if status!=str(200):  
+                raise ValueError,'Error status=%s' % str(status)
+                return False
+            
+            conn = httplib.HTTPConnection('byfiles.storage.msn.com', 80)
+            conn.sock = proxy
+        else:
+            conn = httplib.HTTPConnection('byfiles.storage.msn.com', 80)
+        try:
+            conn.request("GET", 'http://byfiles.storage.msn.com'+url, headers=hdrs)
+            response = conn.getresponse()
+        except:
+            return
+        stat = response.status
+        reas = response.reason
+        
+        if stat != 200:
+            # YouFail
+            return False
+        data = response.read()
+        #print "DP:", len(data), stat, reas
+        if os.name == "nt":
+            tempfolder = os.environ['TEMP'] + os.sep + "emsnpic"
+            tempfolder = unicode(tempfolder)
+        else:
+            tempfolder = '/tmp/emsnpic'
+        f = open(tempfolder, 'wb')
+        f.write(data)
+        f.close()
+        self.emit('self-dp-changed', tempfolder)
+
+        return False
+ 
+    def onSetDP(self, response):
+        #print 'onSetDP:'+str(response)
+        if response.status[0] == 500 and not self.firstSetDpFail:
+            self.firstSetDpFail = True
+            # delete relationship
+            soap.requests.delete_relationship1(self.proxy, self.affinityCache, \
+                self.dpid, self.cid, self.onDeleteRelationship1)
+        
+    def onDeleteRelationship1(self, response):
+        #print 'onDelete1:'+str(response)
+        #print response.body
+        if response.status[0] != 200:
+            soap.requests.update_dp(self.proxy, self.affinityCache, self.cid, \
+                self.config.glob['Id'], 'png', base64.b64encode(self.msnobj.data), 
+                self.onSetDP)
+        else:
+            soap.requests.delete_relationship2(self.proxy, self.affinityCache, \
+                self.dpid, self.rid, self.onDeleteRelationship2)            
+
+    def onDeleteRelationship2(self, response):
+        #print 'onDelete2:'+str(response)
+        #print response.body
+        if response.status[0] == 200:
+            soap.requests.update_dp(self.proxy, self.affinityCache, self.cid, \
+                self.config.glob['Id'], 'png', base64.b64encode(self.msnobj.data), \
+                self.onCreateRelationships)
+
+    def onCreateRelationships(self,response):
+        #print 'onCreate:'+str(response)
+        if response.status[0] == 200:
+            try:
+                document_rid = response.body.split('</CreateDocumentResult>')[0].split('<CreateDocumentResult>')[1]
+                soap.requests.create_relationships(self.proxy, self.affinityCache, self.rid, \
+                    document_rid, self.onFindDocument)
+            except:
+                pass
+
+    def onFindDocument(self, response):
+        #print 'onFind'+str(response)   
+        if response.status[0] == 200:
+            soap.requests.find_document(self.proxy, self.affinityCache,self.cid,\
+                                        self.onEnd)
+
+    def onEnd(self,response):
+        #print 'onEnd:'+str(response)
+        #print response.body
+        try:
+            self.dpid = response.body.split('</ResourceID>')[0].split('<ResourceID>')[1]
+        except:
+            #let the dpid as it was before
+            pass
+
+    def reRequestProfile(self, response):
+        ''' requests the profile again, after creating it (?) '''
+        self.triedCreatingProfile = True
+        if response.status[0] == 200:        
+            soap.requests.get_profile(self.proxy, self.cid, self.onGetProfile)
 
     def addUser(self, email, group, *callback_and_args):
         '''add an user to the friend list'''
@@ -529,7 +683,8 @@ class ProfileManager(gobject.GObject):
 
         if not initial and self.affinityCache != '':
             soap.requests.update_profile(self.proxy, self.affinityCache, \
-                self.rid, nick, self.personalMessage, self.onNickChanged, oldNick)
+                self.rid, common.escape(nick), \
+                common.escape(self.personalMessage), self.onNickChanged, oldNick)
 
     def changeAlias(self, user, alias):
         alias = alias.decode('utf-8', 'replace').encode('utf-8')
@@ -543,6 +698,7 @@ class ProfileManager(gobject.GObject):
             alias, self.onAliasChanged, user, oldAlias)
 
     def onNickChanged(self, response, oldNick):
+        return # shhht! user exceeded the limit can be bad
         if response.status[0] != 200:
             #self.contactManager.setContactNick(self.user, oldNick)
             self.emit('self-nick-changed', self.nick, oldNick)
@@ -550,6 +706,7 @@ class ProfileManager(gobject.GObject):
                 common.parseSoapFault(response))
 
     def onPmChanged(self, response, oldPm):
+        return # shhht! user exceeded the limit can be bad
         if response.status[0] != 200:
             self.emit('self-personal-message-changed', self.personalMessage, oldPm)
             self.emit('error', 'pm-change-error',
@@ -586,7 +743,8 @@ class ProfileManager(gobject.GObject):
             self.updateUUX()
             if self.affinityCache != '':
                 soap.requests.update_profile(self.proxy, self.affinityCache, \
-                    self.rid, self.nick, self.personalMessage, self.onPmChanged, oldPm)
+                    self.rid, common.escape(self.nick), \
+                    common.escape(self.personalMessage), self.onPmChanged, oldPm)
             self.emit('self-personal-message-changed', self.user, pm)
         else:
             common.debug("duplicate pm")
