@@ -51,6 +51,8 @@ import soap.templates
 import common
 import string
 import base64
+# gzipped requests ftw!
+import StringIO, gzip
 
 class Msnp(ProfileManager.ProfileManager):
     '''This class give support to the MSNP15 protocol to use the MSN Messenger network'''
@@ -113,6 +115,8 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,gobject.TYPE_STRING)),
         'self-current-media-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
+        'self-dp-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            (gobject.TYPE_STRING,)),
 
         'new-conversation' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
@@ -182,6 +186,8 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT,)),
         'finished-file-transfer' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_PYOBJECT,gobject.TYPE_PYOBJECT)),
+        # used to prevent notifications at login
+        'enable-notifications' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
     }
 
     ## constants (ftw!)
@@ -198,10 +204,11 @@ class Msnp(ProfileManager.ProfileManager):
     # TODO: ADD WEBCAM IF USER PREFERENCE TELL TO SHOW AND IMPORT WEBCAMDEVICE DOESN'T GIVE ERRORS
 
     def __init__(self, host, port, user, password, \
-        userConfigDir, proxy = None, canUseP4=False):
+        userConfigDir, proxy = None, canUseP4=False, config=None):
         '''Constructor, intialize variables.'''
-        gobject.GObject.__init__(self)
-
+        #gobject.GObject.__init__(self)
+        ProfileManager.ProfileManager.__init__(self, config)
+ 
         if proxy == None:
             self.socket = Socket.Socket(host, port)
         else:
@@ -222,6 +229,8 @@ class Msnp(ProfileManager.ProfileManager):
         self.nick = ''
 
         self.status = 'FLN'
+        
+        self.canNotify = False
 
         self.switchboards = [] # the switchboards to process
         self.switchboardsByTid = {}
@@ -229,7 +238,14 @@ class Msnp(ProfileManager.ProfileManager):
         self.signals = [] # gobject signals to disconnect on logout
         self.selfSignals = [] # msnp signals
 
+        # try creating a profile only once, if it doesn't exist
+        self.triedCreatingProfile = False
+        # don't try to update the profile if there's no cache
         self.affinityCache = ''
+        # don't loop setting dp
+        self.firstSetDpFail = False
+        # id of stored dp
+        self.dpid = ''
 
         self.contactManager = ContactData.ContactList({})
         self.msnObjectsManager = Msnobj.MsnObjectsManager(user)
@@ -506,6 +522,7 @@ class Msnp(ProfileManager.ProfileManager):
             "Content-Length": str(len(body)),
             "Connection": "Keep-Alive",
             "Cache-Control": "no-cache",
+            "Accept-encoding": "gzip", # highly improves bandwidth usage
         }
 
         succeeded = False
@@ -531,7 +548,7 @@ class Msnp(ProfileManager.ProfileManager):
                         proxy.sendall(proxy_pieces)
                         response = proxy.recv(8192) 
                         status=response.split()[1]
-                        if status!=str(200):  raise 'Error status=',str(status)
+                        if status!=str(200):  raise ValueError,'Error status=%s' % str(status)
 
                         # trivial setup for ssl socket
                         if HAVE_PY25:
@@ -553,6 +570,12 @@ class Msnp(ProfileManager.ProfileManager):
 
             if response:
                 data = response.read()
+                isGzipd = response.getheader('Content-Encoding', '')
+                if isGzipd == 'gzip':
+                    # data is gzipped, unzipit!
+                    cstream = StringIO.StringIO(data)
+                    gzpr = gzip.GzipFile(fileobj=cstream)
+                    data = gzpr.read()
             else:
                 raise common.AuthError, "Can't connect to HTTPS server: " + \
                     str(e)
@@ -740,6 +763,9 @@ class Msnp(ProfileManager.ProfileManager):
             # have something to do with this, but this seems safer
             self.accountConfirmed = False
             self.emit('account-unconfirmed')
+        elif command == "PRP" and self.profile_retrieved and not self.canNotify:
+            self.emit('enable-notifications')
+            self.canNotify = True
 
     def parseUBX(self, command, tid, params, payload):
         '''this function parses the UBX payload, and sets the personal
@@ -986,6 +1012,8 @@ class Msnp(ProfileManager.ProfileManager):
             if myself != None:
                 myself.displayPicturePath = filename
 
+            self.updateDisplayPicture()
+
         if self.status != 'FLN':
             self.changeStatus(self.status)
 
