@@ -381,6 +381,8 @@ class FTSender(Base):
         self.app_id = '2' 
         
         self.context = FTContext()
+        if os.name == "nt":
+            filename = unicode(filename)
         self.context.filename = filename
         #self.context.preview = base64.b64encode( self.data )
         self.context.file_size = os.stat(filename).st_size
