@@ -429,7 +429,7 @@ class HtmlHandler:
                 ## hackable ;)
                 loader = gtk.gdk.PixbufLoader()
                 loader.write(mem); loader.close()
-                
+
                 anchor = self.textbuf.create_child_anchor(self.iter)
                 img = AnimatedResizableImage(100, 100, self.canResize)
                 img.set_tooltip(attrs['alt'])
@@ -437,6 +437,7 @@ class HtmlHandler:
                 img.show()
                 self.textview.add_child_at_anchor(img, anchor)
                 self.textview.scrollLater()
+                self.textview.emotes[anchor] = img
             
             except Exception, ex:
                 pixbuf = None
@@ -666,6 +667,11 @@ class HtmlTextView(gtk.TextView):
         self._changed_cursor = False
         self.linkColor = "#0000FF"
 
+        self.connect('copy-clipboard', self._on_copy_clipboard)
+        self.clipboard = gtk.Clipboard(selection=gtk.gdk.atom_intern("CLIPBOARD"))
+        self.get_buffer().add_selection_clipboard(self.clipboard)
+        self.emotes = {}
+
         self.connect("motion-notify-event", self.__motion_notify_event)
         self.connect("leave-notify-event", self.__leave_event)
         self.connect("enter-notify-event", self.__motion_notify_event)
@@ -845,6 +851,46 @@ class HtmlTextView(gtk.TextView):
         if not self.isScrollLocked():
             # very ugly but quite effective.
             gobject.timeout_add(200, self.scrollToBottom, True)
+
+    def _on_copy_clipboard(self, textview):
+        ''' replaces the copied text with a new text with the
+        alt text of the images selected at copying '''
+        buffer = textview.get_buffer()
+        if buffer.get_has_selection():
+            iterStart, iterEnd = buffer.get_selection_bounds()
+            if iterStart.get_offset() > iterEnd.get_offset():
+                temp = start.copy()
+                iterStart = iterEnd.copy()
+                iterEnd = temp.copy() #set the right begining
+
+            text = buffer.get_slice(iterStart, iterEnd)
+
+            #TODO: magic string '\xef\xbf\xbc', object replacement special char
+            while iterStart.forward_search('\xef\xbf\xbc', \
+                             gtk.TEXT_SEARCH_VISIBLE_ONLY):
+
+                iterPos, iterEnd = iterStart.forward_search('\xef\xbf\xbc', \
+                                  gtk.TEXT_SEARCH_VISIBLE_ONLY)
+                anchor = iterPos.get_child_anchor()
+                if anchor and anchor.get_widgets():
+                    widget = anchor.get_widgets()[0]
+                    if isinstance(widget, gtk.EventBox):
+                        alt = anchor.get_widgets()[0].child.get_tooltip_text()
+                    else:
+                        alt = anchor.get_widgets()[0].get_tooltip_text()
+                elif anchor is None:
+                    alt = ''
+                
+                text = text.replace('\xef\xbf\xbc', alt, 1)
+
+                iterStart = iterEnd
+
+            self.clipboard.set_text(text)
+            self.clipboard.store()
+
+    def clear(self):
+        self.get_buffer().set_text('')
+        self.emotes = {}
             
 if __name__ == '__main__':
     sw = gtk.ScrolledWindow()
