@@ -127,8 +127,8 @@ class MainClass( Plugin.Plugin ):
             _('Change the status to away'))
         self.Slash.register('idle', self.slash_idle,
             _('Change the status to idle'))
-        self.Slash.register('invis', self.slash_invis,
-            _('Change the status to invisible'))
+        self.Slash.register('logout', self.slash_logout,
+            _('Logs you out'))
 
         self.enabled = True
 
@@ -165,11 +165,19 @@ class MainClass( Plugin.Plugin ):
         contacts = self.controller.contacts
         data = slash_action.params
         name = slash_action.name
-        if not data:
-            slash_action.outputText(_("Usage /%s contact" % name))
+        if name == "add" and (data == "" or data.find("@") == -1):
+            slash_action.outputText(_("Usage /%s contact_email" % name))
             return
+        if name != "add":
+            if data == "":
+                slash_action.outputText(_("No user specified, applying action to current contact.\n Usage /%s contact_email" % name))
+                data = slash_action.conversation.userMail
+            elif data.find("@") == -1:
+                slash_action.outputText(_("%1 is not a valid parameter. Usage /%2 contact_email") % (data, name))
+                return
+
         if name == 'add':
-            contacts.add(data)
+            contacts.add(data, "")
         elif name == 'block':
             contacts.block(data)
         elif name == 'unblock':
@@ -220,23 +228,23 @@ class MainClass( Plugin.Plugin ):
         else:
             slash_action.outputText(_('Usage: /exec <system command>'))
 
-    def slash_offline(self, slash_action):
-        self.controller.contacts.set_status(0)
+    def slash_logout(self, slash_action):
+        self.controller.logout()
 
     def slash_online(self, slash_action):
-        self.controller.contacts.set_status(1)
+        self.controller.contacts.set_status("NLN")
 
     def slash_busy(self, slash_action):
-        self.controller.contacts.set_status(2)
+        self.controller.contacts.set_status("BSY")
 
     def slash_away(self, slash_action):
-        self.controller.contacts.set_status(3)
+        self.controller.contacts.set_status("AWY")
 
     def slash_idle(self, slash_action):
-        self.controller.contacts.set_status(4)
+        self.controller.contacts.set_status("IDL")
 
-    def slash_invis(self, slash_action):
-        self.controller.contacts.set_status(5)
+    def slash_offline(self, slash_action):
+        self.controller.contacts.set_status("HDN")
 
     def stop( self ):
         '''stop the plugin'''
@@ -258,7 +266,7 @@ class MainClass( Plugin.Plugin ):
         self.Slash.unregister('busy')
         self.Slash.unregister('away')
         self.Slash.unregister('idle')
-        self.Slash.unregister('invis')
+        self.Slash.unregister('logout')
         self.enabled = False
 
     def check( self ):
