@@ -21,6 +21,7 @@ import socket
 import urllib
 import urllib2
 import gobject
+import re
 
 import Plugin
 import currentSong
@@ -30,14 +31,20 @@ import paths
 COVERART_PATH = os.path.join(paths.HOME_DIR, '.covers', '')
 BANSHEE_PATH = os.path.join(paths.HOME_DIR, '.cache/album-art','')
 
+PLUGIN_DESCRIPTION = _( 'Show a personal message with the current song' \
+    ' played in multiple players.' )
+PLUGIN_AUTHORS = { 'Mariano Guerra' : 'luismarianoguerra gmail com' }
+PLUGIN_WEBSITE = 'http://emesene.org'
+PLUGIN_DISPLAYNAME = _( 'CurrentSong' )
+PLUGIN_NAME = 'CurrentSong'
+
 class MainClass( Plugin.Plugin ):
     '''Main plugin class'''
-    description = _( 'Show a personal message with the current song' \
-    ' played in multiple players.' )
-    authors = { 'Mariano Guerra' : 'luismarianoguerra gmail com' }
-    website = 'http://emesene.org'
-    displayName = _( 'CurrentSong' )
-    name = 'CurrentSong'
+    description = PLUGIN_DESCRIPTION
+    authors = PLUGIN_AUTHORS
+    website = PLUGIN_WEBSITE
+    displayName = PLUGIN_DISPLAYNAME
+    name = PLUGIN_NAME
     
     def __init__( self, controller, msn ):
         '''Constructor'''
@@ -47,12 +54,11 @@ class MainClass( Plugin.Plugin ):
         
         self.controller = controller
         
-        self.description = _( 'Show a personal message with the current song' \
-            ' played in multiple players.' )
-        self.authors = { 'Mariano Guerra' : 'luismarianoguerra gmail com' }
-        self.website = 'http://emesene.org'
-        self.displayName = _( 'CurrentSong' )
-        self.name = 'CurrentSong'
+        self.description = PLUGIN_DESCRIPTION
+        self.authors = PLUGIN_AUTHORS
+        self.website = PLUGIN_WEBSITE
+        self.displayName = PLUGIN_DISPLAYNAME
+        self.name = PLUGIN_NAME
         
         self.configWindow = None
         self.statusLabel = None
@@ -64,8 +70,6 @@ class MainClass( Plugin.Plugin ):
         self.config = controller.config
         self.config.readPluginConfig(self.name)
         
-        self.oldavatar = None
-        
         self.setPlayer( self.config.getPluginValue( self.name, 'player', \
             'CurrentSong' ) )
         self.player.setStyle( self.config.getPluginValue( self.name, 'style', \
@@ -80,7 +84,7 @@ class MainClass( Plugin.Plugin ):
         self.mediaEnabledId = 0
         self.coverAvatar = Plugin.Function( self.getCoverAvatar, \
             self.setCoverAvatar )
-
+        
     def start( self ):
         '''start the plugin'''
         if not os.path.isdir(COVERART_PATH):
@@ -101,7 +105,20 @@ class MainClass( Plugin.Plugin ):
             'change::mediaEnabled', self.onMediaEnabled)
             
         self.enabled = True
-    
+
+        self.original_avatar = self.config.user['avatarPath']
+
+        self.doNotSaveAvatar = False
+
+        self.updateAvatarId = self.controller.connect('avatar-changed', self.updateAvatar)    
+
+    def updateAvatar(self, controller, path=None):
+        if path == None:
+            path = self.config.user['avatarPath']
+
+        if not self.doNotSaveAvatar:
+            self.original_avatar = path
+
     def showHelp(self):
         msg = 'Help:'
         for (cmd, val) in self.dictCommand.iteritems():
@@ -159,18 +176,24 @@ class MainClass( Plugin.Plugin ):
         self.controller.mainWindow.userPanel.mediaButton.hide()
         self.controller.mainWindow.userPanel.mediaButton.set_active(False)
         
-        if self.oldavatar:
-            self.controller.changeAvatar(self.oldavatar)
-        self.oldavatar = None
+        if self.avatar and self.original_avatar:
+            self.controller.changeAvatar(self.original_avatar)
+
         self.controller.config.disconnect(self.mediaEnabledId)
         
         self.enabled = False
 
+        self.controller.disconnect(self.updateAvatarId)
+
     def onMediaEnabled(self, config, value, oldvalue):
         '''Called when the media button is toggled'''
-        print "onMediaEnabled"
-        self.action(True)
+        # print "Current song plugin: onMediaEnabled ["+value+"]"
         
+        self.action(True)
+
+        if self.avatar and value == "0" and self.original_avatar:
+            self.controller.changeAvatar(self.original_avatar)
+       
     def action(self, force=False):
         if not self.enabled or not self.config.user['mediaEnabled']:
             return True
@@ -183,7 +206,7 @@ class MainClass( Plugin.Plugin ):
                 self.setPlayer(None)
                 check = True
             
-            # USEFULL for LAST.FM plug 
+            # USEFUL for LAST.FM plug 
             # self.controller.emit('media-changed',self.player.getSongDict())
             # dx note: wtf?
 
@@ -207,15 +230,19 @@ class MainClass( Plugin.Plugin ):
         ''' get avatar cover art '''
         path = self.player.getCoverPath()
         if path and os.path.exists(path):
+            print "Current song plugin : getCoverPath : [" + path + "]"
             return path
 
         path = self.search_local_image()  
         if path and os.path.exists(path):
+            print "Current song plugin : getCoverPath : [" + path + "]"
             return path
 
         if remote:
             try:
-                return self.search_remote_image()
+                path = self.search_remote_image()
+                print "Current song plugin : getCoverPath : [" + path + "]"
+                return path
             except:
                 # handle connection errors
                 pass
@@ -223,13 +250,15 @@ class MainClass( Plugin.Plugin ):
     def setCoverAvatar(self, path):
         ''' set avatar cover art '''
         if path != None and os.path.exists(path):
-            self.oldavatar = self.config.user['avatarPath']
+            self.doNotSaveAvatar = True
             self.controller.changeAvatar(path)
+            self.doNotSaveAvatar = False
             return True
         if not self.player.isPlaying() or not self.player.isRunning():
-            if self.oldavatar:
-                self.controller.changeAvatar(self.oldavatar)
-            self.oldavatar = None
+            if self.original_avatar:
+                self.doNotSaveAvatar = True
+                self.controller.changeAvatar(self.original_avatar)
+                self.doNotSaveAvatar = False
             return False
         return False
 
@@ -244,12 +273,23 @@ class MainClass( Plugin.Plugin ):
                  and x != 'CurrentSong' ]
         
     def setPlayer( self, name ):
-        '''try to set the player object to the name given by the name parameter
-        if not set the dummy player to have something to play with'''
+        players = self.getPluginNames()     
         
-        players = self.getPluginNames()
-        self.playername = name
+        if name == _('Autodetect'):
+            for n in players:
+                if n.lower() != 'lastfm':
+                    print "Current song plugin: Trying " + n
+                    if self._setPlayer(n, players) == 'loaded':
+                        if not self.usingDummy and self.player.isRunning():
+                            return
+        else:
+            self._setPlayer(name, players)
+        
+    def _setPlayer(self, name, players):
+        '''try to set the player object to the name given by the name parameter'''
 
+        self.playername = name
+        
         error = '' 
         if name in players:
             try:
@@ -260,6 +300,7 @@ class MainClass( Plugin.Plugin ):
                 print "error initializing CurrentSong player:", e
                 error = e
             else:
+                self.player.log('info', _('Player: ') + name)
                 status, message = self.player.getStatus()
                 self.player.log(status and 'info' or 'error', \
                     'getStatus: ' + message)
@@ -268,7 +309,7 @@ class MainClass( Plugin.Plugin ):
                     self.player.status = 'error'
                 
                 self.dictCommand = self.player.dictCommand
-                return
+                return 'loaded'
         self.player = currentSong.CurrentSong()
         self.usingDummy = True
         if error:
@@ -297,9 +338,13 @@ class MainClass( Plugin.Plugin ):
         
         artist = self.player.artist.encode('utf8')
         album = self.player.album.encode('utf8')
-        file_dsc = BANSHEE_PATH + artist.replace(' ', '') + '-' + album.replace(' ', '') + '.jpg'
+        
+        bartist = re.sub("\W", "", artist).lower()
+        balbum = re.sub("\W", "", album).lower()
+        file_dsc = BANSHEE_PATH + bartist + '-' + balbum + '.jpg'
         if os.path.exists(file_dsc):
             return file_dsc
+        
         file_dsc = COVERART_PATH + artist + '-' + album + '.jpg'
         if os.path.exists(file_dsc):
             return file_dsc
@@ -311,6 +356,9 @@ class MainClass( Plugin.Plugin ):
 
         artist = self.player.artist.encode('utf8')
         album = self.player.album.encode('utf8')
+        
+        if len(artist) == 0 and len(album) == 0:
+            return None
 
         dest_filename = COVERART_PATH + artist + '-' + album + '.jpg'
 
@@ -318,6 +366,9 @@ class MainClass( Plugin.Plugin ):
             urllib.quote_plus(artist) + "+" + urllib.quote_plus(album) + \
             "&itempage=1&newsearch=1&searchindex=Music"
 
+        # This is useful to see if we're searching for the right song
+        print "Current song plugin: " + url
+
         albumart = urllib.urlopen(url).read()
         image_url = ""
 
@@ -344,6 +395,8 @@ class MainClass( Plugin.Plugin ):
             'remotefetch', '0') == '1'
 
         #self.updateCustomConf()
+        plugin_names = self.getPluginNames()
+        plugin_names.insert(0, _('Autodetect'))
         l = []
         # name, optionType, label, description, value, options
         l.append(Plugin.Option('style', str, _('Display style'), \
@@ -351,7 +404,7 @@ class MainClass( Plugin.Plugin ):
             'variables are %title, %artist and %album'), style))
         l.append(Plugin.Option('player', list, _('Music player'), \
             _('Select the music player that you are using'), player, \
-            self.getPluginNames(), self.playerChanged))
+            plugin_names, self.playerChanged))
         
         self.statusLabel = gtk.Label()
         status_timeout = gobject.timeout_add(2000, self.updateStatus)
@@ -387,7 +440,6 @@ class MainClass( Plugin.Plugin ):
                 self.setPlayer( response[ 'player' ].value )
                 self.config.setPluginValue( self.name, 'player', \
                     response[ 'player' ].value )
-                
             if response.has_key( 'style' ):
                 self.player.setStyle( response[ 'style' ].value )
                 self.config.setPluginValue( self.name, 'style', \
