@@ -718,7 +718,7 @@ class Facebook(object):
 class MainClass( Plugin.Plugin ):
     '''Main plugin class
     This plugins synchronizes Emesene with your Facebook life'''
-    description = _('Synchronize Emesene with your Facebook status and profile picture, and more !')
+    description = _('Synchronize emesene with your Facebook status, profile picture and more!')
     authors = { 'Mehdi Rejraji' : 'mehd36 at gmail dot com' }
     website = ''
     displayName = 'Facebook'
@@ -729,7 +729,7 @@ class MainClass( Plugin.Plugin ):
 
         Plugin.Plugin.__init__( self, controller, msn)
 
-        self.description = _('Synchronize Emesene with your Facebook status and profile picture, and more !')
+        self.description = _('Synchronize emesene with your Facebook status, profile picture and more!')
         self.authors = { 'Mehdi Rejraji' : 'mehd36 at gmail dot com' }
         self.website = ''
         self.displayName = 'Facebook'
