@@ -16,14 +16,12 @@
 #    along with emesene; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-import os
 import gtk
 import time
 import gobject
 import pango
 
 import Plugin
-import stock
 import dialog
 import desktop
 
@@ -34,18 +32,18 @@ from Theme import resizePixbuf
 
 growFactor = 20 # the number of pixels to grow every iteration
 
-class PixmapDialog(gtk.Window):
+class PixmapDialog(gtk.Dialog):
     '''a dialog to set Notification Pixmap'''
-    def __init__(self, response, filename, font, color, online, offline, \
+    def __init__(self, filename, font, color, online, offline, \
                 newMsg, typing, newMail, started, idle, position, scroll):
 
-        gtk.Window.__init__(self)
-        self.set_keep_above(True)
-        self.set_title(_('Notification Config'))
+        gtk.Dialog.__init__(self , _('Notification Config'), None, \
+            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, \
+            (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT, \
+            gtk.STOCK_CANCEL, gtk.RESPONSE_CLOSE))
         self.set_border_width(4)
         self.set_position(gtk.WIN_POS_CENTER)
-
-        self.response_ok = response
+        self.vbox.set_spacing(4)
 
         self.filename = filename
         self.fontdesc = font
@@ -69,31 +67,27 @@ class PixmapDialog(gtk.Window):
         except:
             print 'Font Error'
 
+        self.fontlabel = gtk.Label(_("Font: "))
+
         self.fonttype = gtk.ToolButton()
         self.fonttype.set_stock_id(gtk.STOCK_SELECT_FONT)
 
         self.fontColor = gtk.ToolButton()
         self.fontColor.set_stock_id(gtk.STOCK_SELECT_COLOR)
 
-        try:
-            pixbuf = gtk.gdk.pixbuf_new_from_file(self.filename)
-            pixbuf = resizePixbuf(pixbuf, 24,24)
-            self.image.set_from_pixbuf(pixbuf)
-        except:
-            self.filename = None
+        self.updateImage()
 
         self.button = gtk.Button(_('Image'))
 
         self.hbox.pack_start(self.image)
         self.hbox.pack_start(self.button)
 
-        self.lbox.pack_start(self.fonttype)
-        self.lbox.pack_start(self.fontColor)
-
-        self.vbox = gtk.VBox(spacing=4)
+        self.lbox.pack_start(self.fontlabel, False, False, 5)
+        self.lbox.pack_start(self.fonttype, False, False)
+        self.lbox.pack_start(self.fontColor, False, False)
+        self.lbox.pack_start(self.sample, True, True)
 
         self.vbox.pack_start(self.hbox)
-        self.vbox.pack_start(self.sample)
         self.vbox.pack_start(self.lbox)
 
         self.button.connect('clicked', self.clickPixmap)
@@ -149,39 +143,25 @@ class PixmapDialog(gtk.Window):
         self.vbox.pack_start(self.pbox)
         self.vbox.pack_start(self.sbox)
 
-        b_accept = gtk.Button(stock=gtk.STOCK_OK)
-        b_cancel = gtk.Button(stock=gtk.STOCK_CANCEL)
-
-        b_accept.connect('clicked', self._on_response_ok)
-        b_cancel.connect('clicked', self._on_response_cancel)
-
-        hbbox = gtk.HButtonBox()
-        hbbox.set_spacing(4)
-        hbbox.set_layout(gtk.BUTTONBOX_END)
-
-        hbbox.pack_start(b_cancel, False)
-        hbbox.pack_start(b_accept, False)
-
-        self.vbox.pack_start(hbbox)
-
-        self.add(self.vbox)
-
         self.show_all()
+        
+    def updateImage(self):
+        try:
+            pixbuf = gtk.gdk.pixbuf_new_from_file(self.filename)
+            pixbuf = resizePixbuf(pixbuf, 128, 200)
+            self.image.set_from_pixbuf(pixbuf)
+            self.image.show()
+        except:
+            self.filename = None
+            self.image.hide()
 
     def clickPixmap(self, arg):
         def _on_image_selected(response, path):
-            if response == stock.ACCEPT:
+            if response == gtk.RESPONSE_ACCEPT:
                 self.filename = path
-            try:
-                pixbuf = gtk.gdk.pixbuf_new_from_file(self.filename)
-                pixbuf = resizePixbuf(pixbuf, 24, 24)
-                self.image.set_from_pixbuf(pixbuf)
-                self.image.show()
-            except:
-                self.filename = None
-                self.image.hide()
+                self.updateImage()
 
-        dialog.ImageChooser(paths.HOME_DIR, _on_image_selected).show()
+        dialog.ImageChooser(paths.HOME_DIR, _on_image_selected).run()
 
     def clickFont(self, arg):
         fontDialog = gtk.FontSelectionDialog(_('Choose a font'))
@@ -209,9 +189,8 @@ class PixmapDialog(gtk.Window):
             self.sample.set_use_markup(True)
         colorDialog.destroy()
 
-    def _on_response_ok(self, button):
-         self.destroy()
-         self.response_ok(self.filename, self.fontdesc, self.FColor, \
+    def get_config_values(self):
+        return [self.filename, self.fontdesc, self.FColor, \
                  int(self.chbuOnline.get_active()), \
                  int(self.chbuOffline.get_active()), \
                  int(self.chbuNewMsg.get_active()), \
@@ -220,10 +199,7 @@ class PixmapDialog(gtk.Window):
                  int(self.chbuStarted.get_active()), \
                  int(self.chbuIdle.get_active()), \
                  self.coboPosition.get_active(), \
-                 self.coboScroll.get_active())
-
-    def _on_response_cancel(self, button):
-         self.destroy()
+                 self.coboScroll.get_active()]
 
 class NotificationManager:
     ''' This class manages the creation display and destruction of the notifications. '''
@@ -261,7 +237,7 @@ class NotificationManager:
         g = Notification(pos, scroll, self.offset, string, height, width, \
                 pixmap, closePixmap, callback, params, userPixbuf, font, color)
         g.show()
-		
+                
         gtk.widget_pop_colormap()
 
         self.offset = g.getOffset()
@@ -317,7 +293,7 @@ class Notification(gtk.Window):
                 callback = None, params = None, userPixbuf = None, \
                 font = None, color = None):
 
-        gtk.Window.__init__(self)
+        gtk.Window.__init__(self, type=gtk.gdk.WINDOW_TOPLEVEL)
 
         if corner == 0:
             self.set_gravity(gtk.gdk.GRAVITY_NORTH_WEST)
@@ -328,8 +304,9 @@ class Notification(gtk.Window):
         else:
             self.set_gravity(gtk.gdk.GRAVITY_SOUTH_EAST)
 
-        self.set_property('can-focus', False)
-        self.set_property('accept-focus', False)
+        self.set_accept_focus(False)
+        self.set_decorated(False)
+        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_SPLASHSCREEN)
 
         self.corner = corner
         self.scroll = scroll
@@ -347,13 +324,6 @@ class Notification(gtk.Window):
 
         self.set_geometry_hints(None, min_width=-1, min_height=-1, \
                 max_width=width, max_height=height)
-        self.set_accept_focus(False)
-
-        self.set_decorated(False)
-        self.set_keep_above(False)
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_UTILITY)
-        self.set_skip_taskbar_hint(True)
-        self.set_skip_pager_hint(True)
 
         if pixmap != None:
             self.set_app_paintable(True)
@@ -364,7 +334,6 @@ class Notification(gtk.Window):
                 + escape(str(string)) + '</span>')
         messageLabel.set_use_markup(True)
         messageLabel.set_justify(gtk.JUSTIFY_CENTER)
-        #messageLabel.set_line_wrap(True)
         messageLabel.set_ellipsize(pango.ELLIPSIZE_END)
         try:
             messageLabel.modify_font(pango.FontDescription(font))
@@ -402,6 +371,8 @@ class Notification(gtk.Window):
         lboxEventBox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
         lboxEventBox.connect("button_press_event", self.onClick, params)
         lboxEventBox.add(lbox)
+        
+        self.connect("button_press_event", self.onClick, params)
 
         hbox.pack_start(title, True, True)
         hbox.pack_end(closeEventBox, False, False)
@@ -413,8 +384,6 @@ class Notification(gtk.Window):
 
         self.grow(offset, False)
         self.add(vbox)
-        
-        self.set_focus_on_map(False)
 
         vbox.show_all()
 
@@ -423,7 +392,7 @@ class Notification(gtk.Window):
             self.callback(params)
         self.close()
 
-    def resize(self):
+    def _resize(self):
         ''' change the size and position '''
 
         if self.scroll == 0: 
@@ -447,16 +416,15 @@ class Notification(gtk.Window):
             else:
                 t = gtk.gdk.screen_height() - self.offset - self.height
 
-        gtk.Window.move(self, l, t)
-        gtk.Window.resize(self, self.width, self.height)
+        self.move(l, t)
+        self.resize(self.width, self.height)
 
     def show(self):
         ''' show it '''
-        gtk.Window.show(self)
+        self.show_all()
 
     def close(self , *args):
         ''' hide the Notification '''
-
         self.hide()
 
     def grow(self, offset, animate=True):
@@ -482,7 +450,7 @@ class Notification(gtk.Window):
                 else:
                     self.height += growFactor
 
-        self.resize()
+        self._resize()
 
     def getOffset(self):
         ''' returns next notifications offset '''
@@ -500,7 +468,7 @@ class Notification(gtk.Window):
 
 class MainClass(Plugin.Plugin):
     ''' The notification plugin '''
-    description = _('Show a little window in the bottom-right corner of the screen when someone gets online etc. Use this if you want the old notifications or in Microsoft Windows')
+    description = _('Notifies various events with Messenger-like small windows')
     authors = { 'Mariano Guerra' : 'luismarianoguerra at gmail dot com' }
     website = 'http://emesene-msn.blogspot.com'
     displayName = _('OldNotifications')
@@ -514,7 +482,7 @@ class MainClass(Plugin.Plugin):
 
         self.config = controller.config
 
-        self.description = _('Show a little window in the bottom-right corner of the screen when someone gets online etc. Use this if you want the old notifications or in Microsoft Windows')
+        self.description = _('Notifies various events with Messenger-like small windows')
         self.authors = { 'Mariano Guerra' : 'luismarianoguerra at gmail dot com' }
         self.website = 'http://emesene-msn.blogspot.com'
         self.displayName = _('OldNotifications')
@@ -626,7 +594,7 @@ class MainClass(Plugin.Plugin):
         if not (self.notifyNewMsg and self.notifyEnabled(email)):
             return
 
-	result = self.controller.conversationManager.getOpenConversation(email)
+        result = self.controller.conversationManager.getOpenConversation(email)
         if result != None:
             window, conversation = result
             windowFocus = window.is_active()
@@ -711,12 +679,23 @@ class MainClass(Plugin.Plugin):
         desktop.open(self.controller.hotmail.getLoginPage\
                 (params[0], params[1], params[2]))
 
+    def connect_onoff(self, *args):
+        self.onlineId = self.connect('user-online', self.online)
+        self.offlineId = self.connect('user-offline', self.offline)
+        if self.notifyId is not None: self.disconnect(self.notifyId)
+        self.notifyId = None
+
     def start(self):
         ''' start the plugin '''
 
         self.notificationManager = NotificationManager(128, 200)
-        self.onlineId = self.connect('user-online', self.online)
-        self.offlineId = self.connect('user-offline', self.offline)
+        self.notifyId = None
+        self.onlineId = None
+        self.offlineId = None
+        if self.msn.canNotify:
+            self.connect_onoff()
+        else:
+            self.notifyId = self.connect('enable-notifications', self.connect_onoff)
         self.newMsgId = self.connect('message-received', self.newMsg)
         self.offMsgId = self.connect('offline-message-received', self.offMsg)
         self.typingId = self.connect('switchboard::typing', self.receiveTyping)
@@ -740,8 +719,9 @@ class MainClass(Plugin.Plugin):
     def stop(self):    
         ''' stop the plugin '''
 
-        self.disconnect(self.onlineId)
-        self.disconnect(self.offlineId)
+        if self.onlineId is not None: self.disconnect(self.onlineId)
+        if self.offlineId is not None: self.disconnect(self.offlineId)
+        if self.notifyId is not None: self.disconnect(self.notifyId)
         self.disconnect(self.newMsgId)
         self.disconnect(self.offMsgId)
         self.disconnect(self.typingId)
@@ -761,46 +741,45 @@ class MainClass(Plugin.Plugin):
         return (True, 'Ok')
 
     def configure(self):
-
-        def _on_configure_ok(filename, font, color, online, offline, \
-                newMsg, typing, newMail, started, idle, position, scroll):
-
-            self.filename = filename
-            self.fontname = font
-            self.fontcolor = color
-            self.notifyOnline = online
-            self.notifyOffline = offline
-            self.notifyNewMsg = newMsg
-            self.notifyTyping = typing
-            self.notifyNewMail = newMail
-            self.notifyStarted = started
-            self.notifyIdle = idle
-            self.position = position
-            self.scroll = scroll
-
-            self.config.setPluginValue(self.name, 'filename', filename)
-            self.config.setPluginValue(self.name, 'fontname', font)
-            self.config.setPluginValue(self.name, 'fontcolor', color)
-            self.config.setPluginValue(self.name, 'online', online)
-            self.config.setPluginValue(self.name, 'offline', offline)
-            self.config.setPluginValue(self.name, 'newMsg', newMsg)
-            self.config.setPluginValue(self.name, 'typing', typing)
-            self.config.setPluginValue(self.name, 'newMail', newMail)
-            self.config.setPluginValue(self.name, 'started', started)
-            self.config.setPluginValue(self.name, 'idle', idle)
-            self.config.setPluginValue(self.name, 'position', position)
-            self.config.setPluginValue(self.name, 'scroll', scroll)
-
-            try:
-                self.pixmap, mask = gtk.gdk.pixbuf_new_from_file\
-                        (filename).render_pixmap_and_mask()
-            except:
-                self.pixmap = None
-
-        PixmapDialog(_on_configure_ok, self.filename, \
+        dialog = PixmapDialog(self.filename, \
                 self.fontname, self.fontcolor, self.notifyOnline, \
                 self.notifyOffline, self.notifyNewMsg, self.notifyTyping, \
                 self.notifyNewMail, self.notifyStarted, self.notifyIdle, \
-                self.position, self.scroll).show()
+                self.position, self.scroll)
 
+        response = dialog.run()
+        
+        if response == gtk.RESPONSE_ACCEPT:
+            values = dialog.get_config_values()
+            self.filename = values[0]
+            self.fontname = values[1]
+            self.fontcolor = values[2]
+            self.notifyOnline = values[3]
+            self.notifyOffline = values[4]
+            self.notifyNewMsg = values[5]
+            self.notifyTyping = values[6]
+            self.notifyNewMail = values[7]
+            self.notifyStarted = values[8]
+            self.notifyIdle = values[9]
+            self.position = values[10]
+            self.scroll = values[11]
+            self.config.setPluginValue(self.name, 'filename', self.filename)
+            self.config.setPluginValue(self.name, 'fontname', self.fontname)
+            self.config.setPluginValue(self.name, 'fontcolor', self.fontcolor)
+            self.config.setPluginValue(self.name, 'online', self.notifyOnline)
+            self.config.setPluginValue(self.name, 'offline', self.notifyOffline)
+            self.config.setPluginValue(self.name, 'newMsg', self.notifyNewMsg)
+            self.config.setPluginValue(self.name, 'typing', self.notifyTyping)
+            self.config.setPluginValue(self.name, 'newMail', self.notifyNewMail)
+            self.config.setPluginValue(self.name, 'started', self.notifyStarted)
+            self.config.setPluginValue(self.name, 'idle', self.notifyIdle)
+            self.config.setPluginValue(self.name, 'position', self.position)
+            self.config.setPluginValue(self.name, 'scroll', self.scroll)
+
+            try:
+                self.pixmap, mask = gtk.gdk.pixbuf_new_from_file\
+                        (self.filename).render_pixmap_and_mask()
+            except:
+                self.pixmap = None
+        dialog.destroy()
         return True
