@@ -508,7 +508,7 @@ class MsnPlusMarkup:
 class MainClass( Plugin.Plugin ):
     '''Main plugin class'''
     
-    description = _( 'Messenger Plus like plugin for emesene' )
+    description = _( 'View or remove the annoying colors in nicknames' )
     authors = { 'Roger Duran' : 'RogerDuran at gmail dot com',
          'Mohr Tutchy' : 'mohr dot tutchy at gmail dot com'}
     website = 'http://www.rogerpc.com.ar'
@@ -519,7 +519,7 @@ class MainClass( Plugin.Plugin ):
         
         Plugin.Plugin.__init__( self, controller, msn )
         
-        self.description = _( 'Messenger Plus like plugin for emesene' )
+        self.description = _( 'View or remove the annoying colors in nicknames' )
         self.authors = { 'Roger Duran' : 'RogerDuran at gmail dot com',
                          'Mohr Tutchy' : 'mohr dot tutchy at gmail dot com'}
         self.website = 'http://www.rogerpc.com.ar'
