@@ -52,7 +52,7 @@ class MainClass(Plugin):
         
     def stop(self):
         '''stop the plugin'''
-        self.disconnect(self.shakeWindowId)
+        if self.shakeWindowId is not None: self.disconnect(self.shakeWindowId)
         self.enabled = False
         
     def check(self):
@@ -82,16 +82,16 @@ class MainClass(Plugin):
         #"Butterfly Nudge"
         for i in range(self.iterations):
             win.move(x+self.base_movement, y-self.base_movement) #-down+right
-            gtk.main_iteration()
+            #gtk.main_iteration() #why are these for? it's crashing emesene
             
             win.move(x+self.base_movement, y+self.base_movement) #+up+right
-            gtk.main_iteration()
+            #gtk.main_iteration()
             
             win.move(x-self.base_movement, y-self.base_movement) #-down-left
-            gtk.main_iteration()
+            #gtk.main_iteration()
             
             win.move(x-self.base_movement, y+self.base_movement) #+up-left
-            gtk.main_iteration()
+            #gtk.main_iteration()
             
             win.move(x, y) #start position
-            gtk.main_iteration()
+            #gtk.main_iteration()
