@@ -34,57 +34,40 @@ class Exaile( CurrentSong.DbusBase ):
     def setInterface( self ):
         proxy_obj = self.bus.get_object( IFACE_NAME, IFACE_PATH )
         self.iface = self.module.Interface( proxy_obj, IFACE_NAME )
-        
-    def getCoverPath( self ):
-        if self.iface:
-            return ""
-        else:
-            return None
-     
-    def setCurrentSongData( self ):
-        if self.iface and self.isNameActive(IFACE_NAME):
-            self.artist = self.iface.GetTrackAttr('artist')
-            self.title = self.iface.GetTrackAttr('title')
-            self.album = self.iface.GetTrackAttr('album')
-            if self.artist == None:
-                self.artist = ""
-            if self.title == None:
-                self.title = ""
-            if self.album == None:
-                self.album = ""
-	if not self.isPlaying():
-                self.artist = ""
-                self.title = ""
-                self.album = ""
-        
-
-    def getVersion( self ):
-        try:
-            self.iface.GetVersion()
-        except:
-            return False
-        
-        return True
-    
-    def isPlaying( self ):
-        trackInfo = str(self.iface.Query())
-        if string.split(trackInfo, ", ")[0] == "status: playing":
-            self.playing = True
-            return True
-        else:
-            self.playing = False
-            return False
+                        
+    def isPlaying(self):
+        if self.isRunning():
+            trackInfo = str(self.iface.Query())
+            if string.split(trackInfo, ", ")[0] == "status: playing":
+                return True
+        return False
         
     def check( self ):
-        if not self.iface or not self.isNameActive(IFACE_NAME):
-            return
+        if not self.isRunning():
+            return False
         
-        if self.artist != self.iface.GetTrackAttr('artist') or \
-           self.title != self.iface.GetTrackAttr('title') or \
-           self.album != self.iface.GetTrackAttr('album') or \
-           self.playing != self.isPlaying():
-            self.setCurrentSongData()
-            return True
+        artist = ""
+        title = ""
+        album = ""
+        
+        if self.isPlaying():
+            artist = self.iface.GetTrackAttr('artist')
+            if artist == None:
+                artist = ""
             
+            title = self.iface.GetTrackAttr('title')
+            if title == None:
+                title = ""
+            
+            album = self.iface.GetTrackAttr('album')
+            if album == None:
+                album = ""
+            
+        if self.artist != artist or self.title != title or self.album != album:
+            self.artist = artist
+            self.title = title            
+            self.album = album
+            return True
+
         return False
 
