@@ -23,12 +23,16 @@ if name == 'posix':
     from Audacious import Audacious
     from Banshee import Banshee
     from Exaile import Exaile
+    from Gmusicbrowser import Gmusicbrowser
+    from Guayadeque import Guayadeque    
+    from LastFm import LastFm
     from Listen import Listen
     from QuodLibet import QuodLibet
     from Rhythmbox import Rhythmbox
     from Vagalume import Vagalume
     from Vlc import Vlc
     from Xfmedia import Xfmedia
+    from Songbird import Songbird
     from Spotify import Spotify
     from Xmms import Xmms
     from Xmms2 import Xmms2
