@@ -56,7 +56,7 @@ class MainClass( Plugin.Plugin ):
             
         self.enabled = True
         if self.isbutt == 0 :
-            '''create the gui look'''
+            #create the gui look
             self.Mbox = gtk.HBox(homogeneous=False, spacing=5)
             self.controller.mainWindow.vbox.pack_start(self.Mbox, False, False)
             self.Mbox.show_all()
@@ -68,11 +68,13 @@ class MainClass( Plugin.Plugin ):
             self.img.set_pixel_size(10)
             self.button.set_image(self.img)
             self.button.connect('clicked', self.Mcheck , None)
+            self.button.set_tooltip_text(_('Click here to checked your mail'))
             self.Mbox.pack_start(self.button, False, False)
             self.button.show_all()
             
             self.Tbutton = gtk.Button()
             self.Tbutton.connect('clicked', self.Client , None)
+            self.Tbutton.set_tooltip_text(_('Click here to access your mail'))
             self.Mtext = gtk.Label(_('Not checked yet.'))
             self.Mtext.set_ellipsize( pango.ELLIPSIZE_END )
             self.Mtext.set_use_underline(True)
@@ -90,6 +92,10 @@ class MainClass( Plugin.Plugin ):
             self.name, 'time', '5' ))
         self.source_id = gobject.timeout_add(self.interval, 
                 self.Mcheck, self , None)
+        # Are notifications enabled?
+        self.notifications = bool(int(self.config.getPluginValue(self.name, \
+            'notifications', '0' )))
+             
 
     def Client( self , widget , data=None):
         os.popen(self.config.getPluginValue( self.name, 
@@ -103,6 +109,11 @@ class MainClass( Plugin.Plugin ):
             
         return True
     
+    def IMAP4_connect(self, server_name, use_ssl):
+        '''chooses the righ connection depending on the parameter use_ssl'''
+        if use_ssl == True: return IMAP4_SSL(server_name)
+        else: return IMAP4(server_name)
+    
     def function( self, data ):
         '''this function will run on a thread and the result will be passed
         to the callback function'''
@@ -117,18 +128,17 @@ class MainClass( Plugin.Plugin ):
 
         try:
             try:
-                if use_ssl: server = IMAP4_SSL(server_name)
-                else: server = IMAP4(server_name)
+                server = self.IMAP4_connect(server_name, use_ssl)
                 server.login(user_name, password) 
             except:
                 if '@' in user_name:
                     old_server_name = server_name
                     user_name, server_name = user_name.split('@')
                     try:
-                        server = IMAP4(server_name)
+                        server = self.IMAP4_connect(server_name, use_ssl)
                         server.login(user_name, password) 
                     except:
-                        server = IMAP4(old_server_name)
+                        server = self.IMAP4_connect(old_server_name, use_ssl)
                         server.login(user_name, password) 
                 else:
                     raise
@@ -138,10 +148,11 @@ class MainClass( Plugin.Plugin ):
             r = server.select()
             if r[0] == 'OK' :
                 answer, data = server.search(None, "(UNSEEN)") # Get unread msgs
-                if data[0] == '': numList = []
-                else: numList = [int(k) for k in data[0].split(' ')]
+                # numList contains the identifiers of unread messages
+                try: numList = [int(k) for k in data[0].split(' ')]
+                except: numList = []
  
-                numMes = len(numList)
+                numMes = len(numList) #number of unread messages
                 
                 numList = numList[-5:] # Consider only 5 newest
                 numList.reverse() # newer messages first
@@ -174,13 +185,26 @@ class MainClass( Plugin.Plugin ):
             if numMes >= 1 :
                 params = {'num': numMes, 'user': self.config.getPluginValue(\
                     self.name, 'user','user')}
-                self.Mtext.set_label(_('%(num)s messages for %(user)s') % params)
+                self.Mtext.set_label(\
+                    _('%(num)s new messages for %(user)s') % params)
                 self.Tbutton.set_tooltip_text(mail)
+                
+                if self.notificationsAvailable() and self.notifications:
+                    self.notification_plugin.notify('', _('New email messages'), \
+                        _('There are %(num)s new messages for %(user)s') % params)
             else:
-                self.Mtext.set_label( _('No messages for %s') %  \
+                self.Mtext.set_label( _('No new messages for %s') %  \
                     self.config.getPluginValue( self.name, 'user', 'user'))
                 self.Tbutton.set_tooltip_text(_('No new messages'))
    
+    def notificationsAvailable(self):
+        '''Returns true if NotifyOsdImproved is available and enabled'''
+        self.notification_plugin = \
+            self.controller.pluginManager.getPlugin("NotifyOsdImproved")
+        if self.notification_plugin and self.notification_plugin.enabled:
+            return True
+        else: return False
+    
     def stop( self ):
         self.enabled = False
         gobject.source_remove(self.source_id)
@@ -194,6 +218,10 @@ class MainClass( Plugin.Plugin ):
         dataM = []
         dataM.append( Plugin.Option( 'use_ssl', bool, _('Use SSL'), '', \
             bool(int(self.config.getPluginValue(self.name, 'use_ssl', '1' )))) )
+        dataM.append( Plugin.Option( 'notifications', bool, \
+            _('Email notification - requires: ') + _('NotifyOsdImproved'), '', \
+            bool(int(self.config.getPluginValue(self.name, \
+            'notifications', '0' )))) )
         dataM.append( Plugin.Option( 'time', str, _('Check every [min]:'), '',\
             self.config.getPluginValue( self.name, 'time', '5' )) )
         dataM.append( Plugin.Option( 'server', str, _('IMAP server:'), '', \
@@ -230,6 +258,10 @@ class MainClass( Plugin.Plugin ):
             self.config.setPluginValue(self.name, 'pass', passwd )
             self.config.setPluginValue(self.name, 'client', r['client'].value)
             self.config.setPluginValue(self.name, 'use_ssl', str(int(r['use_ssl'].value)))
+            self.notifications = r['notifications'].value
+            self.config.setPluginValue(self.name, 'notifications', \
+                str(int(self.notifications)))
+                 
             
         #self.start()
         return True
